﻿"use strict";

function EmData(x, y) {
	this.x = x;
	this.y = y;
}

EmData.prototype.mulx = function(factor) {
	var m = Multiplier(factor);
	var d = Divider(factor);
	
	return new EmData( this.x.map(m), this.y.map(d) );
};

EmData.prototype.invx = function(factor) {
	var x = [];
	var y = [];
	
	for (var i = this.x.length - 1; i >= 0; i--) {
		var old = this.x[i];
		x.push( factor / old );
		y.push( this.y[i] * old * old / factor );
	}
	
	return new EmData( x, y );
};

function Planck(temp) {
	this.wavelength = 2897.7554 / temp; // peak wavelength in µm
	this.exitance = 5.670374419e-12 * Math.pow(temp, 4); // in W cm-2

	// wavelength in µm
	// results in W cm-2 µm-1
	this.spectral = function(wave) {
		var x = Math.exp(-14387.687 / (wave * temp));	
		return (37417.749 / Math.pow(wave, 5)) * x / (1 - x);
	};
	
	this.peak = this.spectral(this.wavelength);
}

var LuminEff = (function() {
	var amp = [-0.12135, 1.00198, -0.13573, -0.02864];
	var width = [0.04635117, 0.11245417, 0.03114882, 0.06084076];
	var center = [0.47805029, 0.5545248, 0.501554, 0.65110291];
	var LM_PER_W = 683.002;
	var MIN = 0.36;
	var MAX = 0.78;
	
	function photopic(x) {
		var res = 0;
		for (var i = 0; i < amp.length; i++)
			res += amp[i] * Math.doppler(2 * (x - center[i]) / width[i]);
		return 0.9985 * res;
	}
	
	function lumens(spectrum) {
		var min = Math.max(spectrum.min, MIN);
		var max = Math.min(spectrum.max, MAX)
	
		var product = function(x) { return photopic(x) * spectrum(x); };
		return LM_PER_W * Math.trapez(product, min, max, 100);
	}
	
	return {
		min: MIN,
		max: MAX,
		photopic: photopic,  // Judd–Vos 1978 modified data
		lumens: lumens,
	};
})();

var Spectra = (function() {
	function Doppler(center, width, area) {
		var amp = 0.939437278699651334 / width;
		if (typeof area === 'number')
			amp *= area;

		function spectrum(x) {
			return amp * Math.doppler(2 * (x - center) / width);
		}
		
		spectrum.amplitude = amp;
		spectrum.min = center - 3 * width;
		spectrum.max = center + 3 * width;
		
		return spectrum;
	}
	
	var FL_LINES = [
		Doppler(0.405, 0.004, 0.015),
		Doppler(0.436, 0.004, 0.075),
		Doppler(0.488, 0.005, 0.02),
		Doppler(0.492, 0.020, 0.13),
		Doppler(0.544, 0.013, 0.38),
		Doppler(0.590, 0.020, 0.14),
		Doppler(0.611, 0.008, 0.19),
		Doppler(0.629, 0.020, 0.05)
	];
	
	return {
		Square: function(center, width) {
			var amp = 1 / width;
			width *= 0.5;
		
			function spectrum(x) {
				return Math.abs(x - center) > width ? 0 : amp;
			}
			
			spectrum.amplitude = amp;
			spectrum.min = center - width;
			spectrum.max = center + width;
			
			return spectrum;
		},
	
		Doppler: Doppler,
		
		PCLED: function(pf) {
			var diode1 = Doppler(0.4516, 0.01544, 0.47869);
			var diode2 = Doppler(0.4556, 0.03275, 0.52131);
			var lumin1 = Doppler(0.5295, 0.04787, 0.12619);
			var lumin2 = Doppler(0.5690, 0.08744, 0.44431);
			var lumin3 = Doppler(0.6200, 0.12460, 0.42950);
			var df = 1 - pf;
		
			function spectrum(x) {
				return df * (diode1(x) + diode2(x)) + pf * (lumin1(x) + lumin2(x) + lumin3(x));
			}
			
			spectrum.min = 0.4;
			spectrum.max = 0.7;
			
			return spectrum;
		},
		
		FSLED: function() {
			var comp = [
				Doppler(0.460, 0.030, 0.15),
				Doppler(0.530, 0.110, 0.47),
				Doppler(0.635, 0.090, 0.38)
			];
		
			function spectrum(x) {
				var result = 0;
				comp.forEach(function(f) { result += f(x); })
				return result;
			}
			
			spectrum.min = 0.38;
			spectrum.max = 0.82;
			
			return spectrum;
		},
		
		Fluorescent: function() {
			function spectrum(x) {
				var sum = 0;
				
				FL_LINES.forEach(function(line) {
					sum += line(x);
				});
				
				return sum;
			}
			
			spectrum.min = 0.38;
			spectrum.max = 0.65;
			
			return spectrum;
		},
		
		Blackbody: function(temp) {
			var planck = new Planck(temp);
			var coeff = 1 / planck.exitance;
			
			function spectrum(x) {
				return coeff * planck.spectral(x);
			}
			
			spectrum.amplitude = coeff * planck.peak;
			spectrum.min = 0.01 * planck.wavelength;
			spectrum.max = 100 * planck.wavelength;
			
			return spectrum;
		}
	};
})();

var Solar = (function(){
	var IRRAD = 1366.1;
	
	// 2000 ASTM Standard E-490
	var AM0 = new EmData(
		[ 0.1195, 0.1205, 0.1215, 0.1225, 0.1235, 0.1245, 0.1255, 0.1265, 0.1275, 0.1285, 0.1295, 0.1305, 0.1315, 0.1325, 0.1335, 0.1345, 0.1355, 0.1365, 0.1375, 0.1385, 0.1395, 0.1405, 0.1415, 0.1425, 0.1435, 0.1445, 0.1455, 0.1465, 0.1475, 0.1485, 0.1495, 0.1505, 0.1515, 0.1525, 0.1535, 0.1545, 0.1555, 0.1565, 0.1575, 0.1585, 0.1595, 0.1605, 0.1615, 0.1625, 0.1635, 0.1645, 0.1655, 0.1665, 0.1675, 0.1685, 0.1695, 0.1705, 0.1715, 0.1725, 0.1735, 0.1745, 0.1755, 0.1765, 0.1775, 0.1785, 0.1795, 0.1805, 0.1815, 0.1825, 0.1835, 0.1845, 0.1855, 0.1865, 0.1875, 0.1885, 0.1895, 0.1905, 0.1915, 0.1925, 0.1935, 0.1945, 0.1955, 0.1965, 0.1975, 0.1985, 0.1995, 0.2005, 0.2015, 0.2025, 0.2035, 0.2045, 0.2055, 0.2065, 0.2075, 0.2085, 0.2095, 0.2105, 0.2115, 0.2125, 0.2135, 0.2145, 0.2155, 0.2165, 0.2175, 0.2185, 0.2195, 0.2205, 0.2215, 0.2225, 0.2235, 0.2245, 0.2255, 0.2265, 0.2275, 0.2285, 0.2295, 0.2305, 0.2315, 0.2325, 0.2335, 0.2345, 0.2355, 0.2365, 0.2375, 0.2385, 0.2395, 0.2405, 0.2415, 0.2425, 0.2435, 0.2445, 0.2455, 0.2465, 0.2475, 0.2485, 0.2495, 0.2505, 0.2515, 0.2525, 0.2535, 0.2545, 0.2555, 0.2565, 0.2575, 0.2585, 0.2595, 0.2605, 0.2615, 0.2625, 0.2635, 0.2645, 0.2655, 0.2665, 0.2675, 0.2685, 0.2695, 0.2705, 0.2715, 0.2725, 0.2735, 0.2745, 0.2755, 0.2765, 0.2775, 0.2785, 0.2795, 0.2805, 0.2815, 0.2825, 0.2835, 0.2845, 0.2855, 0.2865, 0.2875, 0.2885, 0.2895, 0.2905, 0.2915, 0.2925, 0.2935, 0.2945, 0.2955, 0.2965, 0.2975, 0.2985, 0.2995, 0.3005, 0.3015, 0.3025, 0.3035, 0.3045, 0.3055, 0.3065, 0.3075, 0.3085, 0.3095, 0.3105, 0.3115, 0.3125, 0.3135, 0.3145, 0.3155, 0.3165, 0.3175, 0.3185, 0.3195, 0.3205, 0.3215, 0.3225, 0.3235, 0.3245, 0.3255, 0.3265, 0.3275, 0.3285, 0.3295, 0.3305, 0.3315, 0.3325, 0.3335, 0.3345, 0.3355, 0.3365, 0.3375, 0.3385, 0.3395, 0.3405, 0.3415, 0.3425, 0.3435, 0.3445, 0.3455, 0.3465, 0.3475, 0.3485, 0.3495, 0.3505, 0.3515, 0.3525, 0.3535, 0.3545, 0.3555, 0.3565, 0.3575, 0.3585, 0.3595, 0.3605, 0.3615, 0.3625, 0.3635, 0.3645, 0.3655, 0.3665, 0.3675, 0.3685, 0.3695, 0.3705, 0.3715, 0.3725, 0.3735, 0.3745, 0.3755, 0.3765, 0.3775, 0.3785, 0.3795, 0.3805, 0.3815, 0.3825, 0.3835, 0.3845, 0.3855, 0.3865, 0.3875, 0.3885, 0.3895, 0.3905, 0.3915, 0.3925, 0.3935, 0.3945, 0.3955, 0.3965, 0.3975, 0.3985, 0.3995, 0.4005, 0.4015, 0.4025, 0.4035, 0.4045, 0.4055, 0.4065, 0.4075, 0.4085, 0.4095, 0.4105, 0.4115, 0.4125, 0.4135, 0.4145, 0.4155, 0.4165, 0.4175, 0.4185, 0.4195, 0.4205, 0.4215, 0.4225, 0.4235, 0.4245, 0.4255, 0.4265, 0.4275, 0.4285, 0.4295, 0.4305, 0.4315, 0.4325, 0.4335, 0.4345, 0.4355, 0.4365, 0.4375, 0.4385, 0.4395, 0.4405, 0.4415, 0.4425, 0.4435, 0.4445, 0.4455, 0.4465, 0.4475, 0.4485, 0.4495, 0.4505, 0.4515, 0.4525, 0.4535, 0.4545, 0.4555, 0.4565, 0.4575, 0.4585, 0.4595, 0.4605, 0.4615, 0.4625, 0.4635, 0.4645, 0.4655, 0.4665, 0.4675, 0.4685, 0.4695, 0.4705, 0.4715, 0.4725, 0.4735, 0.4745, 0.4755, 0.4765, 0.4775, 0.4785, 0.4795, 0.4805, 0.4815, 0.4825, 0.4835, 0.4845, 0.4855, 0.4865, 0.4875, 0.4885, 0.4895, 0.4905, 0.4915, 0.4925, 0.4935, 0.4945, 0.4955, 0.4965, 0.4975, 0.4985, 0.4995, 0.5005, 0.5015, 0.5025, 0.5035, 0.5045, 0.5055, 0.5065, 0.5075, 0.5085, 0.5095, 0.5105, 0.5115, 0.5125, 0.5135, 0.5145, 0.5155, 0.5165, 0.5175, 0.5185, 0.5195, 0.5205, 0.5215, 0.5225, 0.5235, 0.5245, 0.5255, 0.5265, 0.5275, 0.5285, 0.5295, 0.5305, 0.5315, 0.5325, 0.5335, 0.5345, 0.5355, 0.5365, 0.5375, 0.5385, 0.5395, 0.5405, 0.5415, 0.5425, 0.5435, 0.5445, 0.5455, 0.5465, 0.5475, 0.5485, 0.5495, 0.5505, 0.5515, 0.5525, 0.5535, 0.5545, 0.5555, 0.5565, 0.5575, 0.5585, 0.5595, 0.5605, 0.5615, 0.5625, 0.5635, 0.5645, 0.5655, 0.5665, 0.5675, 0.5685, 0.5695, 0.5705, 0.5715, 0.5725, 0.5735, 0.5745, 0.5755, 0.5765, 0.5775, 0.5785, 0.5795, 0.5805, 0.5815, 0.5825, 0.5835, 0.5845, 0.5855, 0.5865, 0.5875, 0.5885, 0.5895, 0.5905, 0.5915, 0.5925, 0.5935, 0.5945, 0.5955, 0.5965, 0.5975, 0.5985, 0.5995, 0.6005, 0.6015, 0.6025, 0.6035, 0.6045, 0.6055, 0.6065, 0.6075, 0.6085, 0.6095, 0.6105, 0.6115, 0.6125, 0.6135, 0.6145, 0.6155, 0.6165, 0.6175, 0.6185, 0.6195, 0.6205, 0.6215, 0.6225, 0.6235, 0.6245, 0.6255, 0.6265, 0.6275, 0.6285, 0.6295, 0.631, 0.633, 0.635, 0.637, 0.639, 0.641, 0.643, 0.645, 0.647, 0.649, 0.651, 0.653, 0.655, 0.657, 0.659, 0.661, 0.663, 0.665, 0.667, 0.669, 0.671, 0.673, 0.675, 0.677, 0.679, 0.681, 0.683, 0.685, 0.687, 0.689, 0.691, 0.693, 0.695, 0.697, 0.699, 0.701, 0.703, 0.705, 0.707, 0.709, 0.711, 0.713, 0.715, 0.717, 0.719, 0.721, 0.723, 0.725, 0.727, 0.729, 0.731, 0.733, 0.735, 0.737, 0.739, 0.741, 0.743, 0.745, 0.747, 0.749, 0.751, 0.753, 0.755, 0.757, 0.759, 0.761, 0.763, 0.765, 0.767, 0.769, 0.771, 0.773, 0.775, 0.777, 0.779, 0.781, 0.783, 0.785, 0.787, 0.789, 0.791, 0.793, 0.795, 0.797, 0.799, 0.801, 0.803, 0.805, 0.807, 0.809, 0.811, 0.813, 0.815, 0.817, 0.819, 0.821, 0.823, 0.825, 0.826, 0.828, 0.83, 0.832, 0.834, 0.836, 0.838, 0.84, 0.842, 0.844, 0.846, 0.848, 0.85, 0.852, 0.854, 0.856, 0.858, 0.86, 0.862, 0.864, 0.866, 0.868, 0.87, 0.872, 0.874, 0.876, 0.878, 0.88, 0.882, 0.884, 0.886, 0.888, 0.89, 0.892, 0.894, 0.896, 0.898, 0.9, 0.902, 0.904, 0.906, 0.908, 0.91, 0.912, 0.914, 0.916, 0.918, 0.92, 0.922, 0.924, 0.926, 0.928, 0.93, 0.932, 0.934, 0.936, 0.938, 0.94, 0.942, 0.944, 0.946, 0.948, 0.95, 0.952, 0.954, 0.956, 0.958, 0.96, 0.962, 0.964, 0.966, 0.968, 0.97, 0.972, 0.974, 0.976, 0.978, 0.98, 0.982, 0.984, 0.986, 0.988, 0.99, 0.992, 0.994, 0.996, 0.998, 1, 1.002, 1.004, 1.006, 1.008, 1.01, 1.012, 1.014, 1.016, 1.018, 1.02, 1.022, 1.024, 1.026, 1.028, 1.03, 1.032, 1.034, 1.036, 1.038, 1.04, 1.042, 1.044, 1.046, 1.048, 1.05, 1.052, 1.054, 1.056, 1.058, 1.06, 1.062, 1.064, 1.066, 1.068, 1.07, 1.072, 1.074, 1.076, 1.078, 1.08, 1.082, 1.084, 1.086, 1.088, 1.09, 1.092, 1.094, 1.096, 1.098, 1.1, 1.102, 1.104, 1.106, 1.108, 1.11, 1.112, 1.114, 1.116, 1.118, 1.12, 1.122, 1.124, 1.126, 1.128, 1.13, 1.132, 1.134, 1.136, 1.138, 1.14, 1.142, 1.144, 1.146, 1.148, 1.15, 1.152, 1.154, 1.156, 1.158, 1.16, 1.162, 1.164, 1.166, 1.168, 1.17, 1.172, 1.174, 1.176, 1.178, 1.18, 1.182, 1.184, 1.186, 1.188, 1.19, 1.192, 1.194, 1.196, 1.198, 1.2, 1.202, 1.204, 1.206, 1.208, 1.21, 1.212, 1.214, 1.216, 1.218, 1.22, 1.222, 1.224, 1.226, 1.228, 1.23, 1.232, 1.234, 1.236, 1.238, 1.24, 1.242, 1.244, 1.246, 1.248, 1.25, 1.252, 1.254, 1.256, 1.258, 1.26, 1.262, 1.264, 1.266, 1.268, 1.27, 1.272, 1.274, 1.276, 1.278, 1.28, 1.282, 1.284, 1.286, 1.288, 1.29, 1.292, 1.294, 1.296, 1.298, 1.3, 1.302, 1.304, 1.306, 1.308, 1.31, 1.312, 1.314, 1.316, 1.318, 1.32, 1.322, 1.324, 1.326, 1.328, 1.33, 1.332, 1.334, 1.336, 1.338, 1.34, 1.342, 1.344, 1.346, 1.348, 1.35, 1.352, 1.354, 1.356, 1.358, 1.36, 1.362, 1.364, 1.366, 1.368, 1.37, 1.372, 1.374, 1.376, 1.378, 1.38, 1.382, 1.384, 1.386, 1.388, 1.39, 1.392, 1.394, 1.396, 1.398, 1.4, 1.402, 1.404, 1.406, 1.408, 1.41, 1.412, 1.414, 1.416, 1.418, 1.42, 1.422, 1.424, 1.426, 1.428, 1.43, 1.432, 1.434, 1.436, 1.438, 1.44, 1.442, 1.444, 1.446, 1.448, 1.45, 1.452, 1.454, 1.456, 1.458, 1.46, 1.462, 1.464, 1.466, 1.468, 1.47, 1.472, 1.474, 1.476, 1.478, 1.48, 1.482, 1.484, 1.486, 1.488, 1.49, 1.492, 1.494, 1.496, 1.498, 1.5, 1.502, 1.504, 1.506, 1.508, 1.51, 1.512, 1.514, 1.516, 1.518, 1.52, 1.522, 1.524, 1.526, 1.528, 1.53, 1.532, 1.534, 1.536, 1.538, 1.54, 1.542, 1.544, 1.546, 1.548, 1.55, 1.552, 1.554, 1.556, 1.558, 1.56, 1.562, 1.564, 1.566, 1.568, 1.57, 1.572, 1.574, 1.576, 1.578, 1.58, 1.582, 1.584, 1.586, 1.588, 1.59, 1.592, 1.594, 1.596, 1.598, 1.6, 1.602, 1.604, 1.606, 1.608, 1.61, 1.612, 1.614, 1.616, 1.618, 1.62, 1.622, 1.624, 1.626, 1.628, 1.63, 1.632, 1.634, 1.636, 1.638, 1.64, 1.642, 1.644, 1.646, 1.648, 1.65, 1.652, 1.654, 1.656, 1.658, 1.66, 1.662, 1.664, 1.666, 1.668, 1.67, 1.672, 1.674, 1.676, 1.678, 1.68, 1.682, 1.684, 1.686, 1.688, 1.69, 1.692, 1.694, 1.696, 1.698, 1.7, 1.702, 1.704, 1.706, 1.708, 1.71, 1.712, 1.714, 1.716, 1.718, 1.72, 1.722, 1.724, 1.726, 1.728, 1.73, 1.732, 1.734, 1.736, 1.738, 1.74, 1.742, 1.744, 1.746, 1.748, 1.75, 1.752, 1.754, 1.756, 1.758, 1.76, 1.762, 1.764, 1.766, 1.768, 1.77, 1.772, 1.774, 1.776, 1.778, 1.78, 1.782, 1.784, 1.786, 1.788, 1.79, 1.792, 1.794, 1.796, 1.798, 1.8, 1.802, 1.804, 1.806, 1.808, 1.81, 1.812, 1.814, 1.816, 1.818, 1.82, 1.822, 1.824, 1.826, 1.828, 1.83, 1.832, 1.834, 1.836, 1.838, 1.84, 1.842, 1.844, 1.846, 1.848, 1.85, 1.852, 1.854, 1.856, 1.858, 1.86, 1.862, 1.864, 1.866, 1.868, 1.87, 1.872, 1.874, 1.876, 1.878, 1.88, 1.882, 1.884, 1.886, 1.888, 1.89, 1.892, 1.894, 1.896, 1.898, 1.9, 1.902, 1.904, 1.906, 1.908, 1.91, 1.912, 1.914, 1.916, 1.918, 1.92, 1.922, 1.924, 1.926, 1.928, 1.93, 1.932, 1.934, 1.936, 1.938, 1.94, 1.942, 1.944, 1.946, 1.948, 1.95, 1.952, 1.954, 1.956, 1.958, 1.96, 1.962, 1.964, 1.966, 1.968, 1.97, 1.972, 1.974, 1.976, 1.978, 1.98, 1.982, 1.984, 1.986, 1.988, 1.99, 1.992, 1.994, 1.996, 1.998, 2, 2.002, 2.004, 2.006, 2.008, 2.01, 2.012, 2.014, 2.016, 2.018, 2.02, 2.022, 2.024, 2.026, 2.028, 2.03, 2.032, 2.034, 2.036, 2.038, 2.04, 2.042, 2.044, 2.046, 2.048, 2.05, 2.052, 2.054, 2.056, 2.058, 2.06, 2.062, 2.064, 2.066, 2.068, 2.07, 2.072, 2.074, 2.076, 2.078, 2.08, 2.082, 2.084, 2.086, 2.088, 2.09, 2.092, 2.094, 2.096, 2.098, 2.1, 2.102, 2.104, 2.106, 2.108, 2.11, 2.112, 2.114, 2.116, 2.118, 2.12, 2.122, 2.124, 2.126, 2.128, 2.13, 2.132, 2.134, 2.136, 2.138, 2.14, 2.142, 2.144, 2.146, 2.148, 2.15, 2.152, 2.154, 2.156, 2.158, 2.16, 2.162, 2.164, 2.166, 2.168, 2.17, 2.172, 2.174, 2.176, 2.178, 2.18, 2.182, 2.184, 2.186, 2.188, 2.19, 2.192, 2.194, 2.196, 2.198, 2.2, 2.202, 2.204, 2.206, 2.208, 2.21, 2.212, 2.214, 2.216, 2.218, 2.22, 2.222, 2.224, 2.226, 2.228, 2.23, 2.232, 2.234, 2.236, 2.238, 2.24, 2.242, 2.244, 2.246, 2.248, 2.25, 2.252, 2.254, 2.256, 2.258, 2.26, 2.262, 2.264, 2.266, 2.268, 2.27, 2.272, 2.274, 2.276, 2.278, 2.28, 2.282, 2.284, 2.286, 2.288, 2.29, 2.292, 2.294, 2.296, 2.298, 2.3, 2.302, 2.304, 2.306, 2.308, 2.31, 2.312, 2.314, 2.316, 2.318, 2.32, 2.322, 2.324, 2.326, 2.328, 2.33, 2.332, 2.334, 2.336, 2.338, 2.34, 2.342, 2.344, 2.346, 2.348, 2.35, 2.352, 2.354, 2.356, 2.358, 2.36, 2.362, 2.364, 2.366, 2.368, 2.37, 2.372, 2.374, 2.376, 2.378, 2.38, 2.382, 2.384, 2.386, 2.388, 2.39, 2.392, 2.394, 2.396, 2.398, 2.4, 2.402, 2.404, 2.406, 2.408, 2.41, 2.412, 2.414, 2.416, 2.418, 2.42, 2.422, 2.424, 2.426, 2.428, 2.43, 2.432, 2.434, 2.436, 2.438, 2.44, 2.442, 2.444, 2.446, 2.448, 2.45, 2.452, 2.454, 2.456, 2.458, 2.46, 2.462, 2.464, 2.466, 2.468, 2.47, 2.472, 2.474, 2.476, 2.478, 2.48, 2.482, 2.484, 2.486, 2.488, 2.49, 2.492, 2.494, 2.496, 2.498, 2.5, 2.52, 2.54, 2.56, 2.58, 2.6, 2.62, 2.64, 2.66, 2.68, 2.7, 2.72, 2.74, 2.76, 2.78, 2.8, 2.82, 2.84, 2.86, 2.88, 2.9, 2.92, 2.94, 2.96, 2.98, 3, 3.02, 3.04, 3.06, 3.08, 3.1, 3.12, 3.14, 3.16, 3.18, 3.2, 3.22, 3.24, 3.26, 3.28, 3.3, 3.32, 3.34, 3.36, 3.38, 3.4, 3.42, 3.44, 3.46, 3.48, 3.5, 3.52, 3.54, 3.56, 3.58, 3.6, 3.62, 3.64, 3.66, 3.68, 3.7, 3.72, 3.74, 3.76, 3.78, 3.8, 3.82, 3.84, 3.86, 3.88, 3.9, 3.92, 3.94, 3.96, 3.98, 4, 4.02, 4.04, 4.06, 4.08, 4.1, 4.12, 4.14, 4.16, 4.18, 4.2, 4.22, 4.24, 4.26, 4.28, 4.3, 4.32, 4.34, 4.36, 4.38, 4.4, 4.42, 4.44, 4.46, 4.48, 4.5, 4.52, 4.54, 4.56, 4.58, 4.6, 4.62, 4.64, 4.66, 4.68, 4.7, 4.72, 4.74, 4.76, 4.78, 4.8, 4.82, 4.84, 4.86, 4.88, 4.9, 4.92, 4.94, 4.96, 4.98, 5, 5.05, 5.1, 5.15, 5.2, 5.25, 5.3, 5.35, 5.4, 5.45, 5.5, 5.55, 5.6, 5.65, 5.7, 5.75, 5.8, 5.85, 5.9, 5.95, 6, 6.05, 6.1, 6.15, 6.2, 6.25, 6.3, 6.35, 6.4, 6.45, 6.5, 6.55, 6.6, 6.65, 6.7, 6.75, 6.8, 6.85, 6.9, 6.95, 7, 7.05, 7.1, 7.15, 7.2, 7.25, 7.3, 7.35, 7.4, 7.45, 7.5, 7.55, 7.6, 7.65, 7.7, 7.75, 7.8, 7.85, 7.9, 7.95, 8, 8.05, 8.1, 8.15, 8.2, 8.25, 8.3, 8.35, 8.4, 8.45, 8.5, 8.55, 8.6, 8.65, 8.7, 8.75, 8.8, 8.85, 8.9, 8.95, 9, 9.05, 9.1, 9.15, 9.2, 9.25, 9.3, 9.35, 9.4, 9.45, 9.5, 9.55, 9.6, 9.65, 9.7, 9.75, 9.8, 9.85, 9.9, 9.95, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 25, 30, 35, 40, 50, 60, 80, 100, 120, 150, 200, 250, 300, 400, 1000 ],
		[ 6.19E-02, 0.5614, 4.901, 1.184, 4.77E-02, 3.43E-02, 2.88E-02, 3.52E-02, 2.13E-02, 1.73E-02, 3.99E-02, 0.1206, 3.98E-02, 4.13E-02, 0.168, 4.57E-02, 3.80E-02, 3.09E-02, 2.92E-02, 3.97E-02, 7.56E-02, 6.08E-02, 4.21E-02, 4.68E-02, 5.11E-02, 5.09E-02, 5.54E-02, 7.09E-02, 8.49E-02, 8.20E-02, 7.96E-02, 8.70E-02, 9.27E-02, 0.1163, 0.1299, 0.2059, 0.2144, 0.1847, 0.1717, 0.1675, 0.1754, 0.1934, 0.2228, 0.2519, 0.2841, 0.2973, 0.4302, 0.3989, 0.3875, 0.4556, 0.5877, 0.6616, 0.688, 0.7252, 0.7645, 0.9067, 1.079, 1.22, 1.403, 1.538, 1.576, 1.831, 2.233, 2.243, 2.244, 2.066, 2.311, 2.7, 3.009, 3.291, 3.569, 3.764, 4.165, 4.113, 3.808, 5.21, 5.427, 6.008, 6.191, 6.187, 6.664, 7.326, 8.023, 8.261, 9.217, 10.25, 10.54, 11.08, 12.65, 15.05, 21.38, 27.92, 33.54, 31.3, 33.15, 40.03, 36.15, 32.27, 35.29, 44.37, 46.92, 47.33, 39.58, 49.65, 63.01, 58.97, 52.29, 39.4, 39.92, 51.95, 47.71, 52.12, 50.97, 53.26, 44.74, 38.97, 51.42, 48.59, 48.44, 41.96, 44.12, 39.56, 51.48, 70.6, 66.53, 60.97, 49.39, 50.4, 55.5, 45.65, 56.38, 60.1, 46.01, 41.55, 51.55, 59.57, 79.3, 101.8, 125.4, 125.1, 104, 85.51, 89.8, 103.6, 165.8, 249.7, 252.7, 249.4, 250.8, 243.8, 238.9, 267.3, 224.4, 197.4, 196.5, 132.6, 175.1, 242.8, 233.8, 159.3, 85.55, 94.63, 208.3, 294.1, 313.5, 235.3, 163.1, 322.7, 336.3, 322.2, 472.7, 601.3, 580.8, 521.9, 535.5, 508.8, 553.2, 509.6, 507.3, 465.5, 484, 420, 455.5, 489, 620.6, 602.5, 594.8, 555.7, 615, 611.4, 496.5, 622.4, 729.2, 655.9, 699.9, 662.9, 633, 633.2, 773.9, 664.9, 710.5, 805.1, 699.5, 688.6, 661.3, 760.8, 875.8, 979.5, 952.7, 917.6, 1061, 1016, 965.7, 954.9, 921.6, 958.9, 943.4, 809.5, 841.8, 921.5, 958.1, 1007, 923.8, 993, 950.6, 795.7, 939.2, 926.4, 901.7, 897.2, 889.8, 1050, 979.5, 907.9, 1033, 1111, 1045, 912.3, 796, 693.6, 991.1, 970.8, 878.1, 997.8, 996.9, 1013, 1152, 1233, 1180, 1101, 1226, 1139, 1175, 1054, 920.2, 900.4, 1062, 1085, 1282, 1327, 1066, 1202, 1082, 791.3, 684.1, 959.7, 1008, 1007, 1004, 984.3, 1174, 1247, 1342, 1019, 582.3, 1026, 1314, 854.5, 928.8, 1522, 1663, 1682, 1746, 1759, 1684, 1674, 1667, 1589, 1628, 1735, 1715, 1532, 1817, 1789, 1756, 1737, 1734, 1842, 1665, 1684, 1701, 1757, 1797, 1582, 1711, 1767, 1695, 1698, 1569, 1587, 1475, 1135, 1686, 1646, 1731, 1670, 1723, 1929, 1806, 1567, 1825, 1713, 1931, 1980, 1909, 1973, 1821, 1891, 2077, 1973, 2027, 2144, 2109, 1941, 1970, 1979, 2034, 2077, 2100, 1971, 2009, 2040, 2055, 2104, 2040, 1976, 2042, 1921, 2015, 1994, 1990, 1877, 2018, 2041, 1991, 2051, 2016, 1956, 2075, 2009, 2076, 2035, 2090, 2023, 2019, 1969, 1830, 1625, 1830, 1914, 1960, 2007, 1896, 1896, 1888, 2058, 1926, 2017, 2018, 1866, 1970, 1857, 1812, 1894, 1934, 1869, 1993, 1961, 1906, 1919, 1916, 1947, 1997, 1867, 1861, 1874, 1900, 1669, 1726, 1654, 1828, 1831, 1906, 1823, 1894, 1958, 1930, 1674, 1828, 1897, 1918, 1952, 1963, 1770, 1923, 1858, 1990, 1871, 1882, 1904, 1832, 1769, 1881, 1825, 1879, 1879, 1901, 1879, 1833, 1863, 1895, 1862, 1871, 1846, 1882, 1898, 1897, 1821, 1846, 1787, 1808, 1843, 1824, 1850, 1861, 1854, 1798, 1829, 1887, 1810, 1860, 1769, 1823, 1892, 1876, 1867, 1830, 1846, 1857, 1783, 1828, 1838, 1853, 1873, 1857, 1860, 1783, 1830, 1848, 1750, 1612, 1813, 1787, 1808, 1796, 1773, 1782, 1805, 1780, 1757, 1774, 1746, 1751, 1719, 1787, 1776, 1763, 1759, 1757, 1743, 1744, 1703, 1746, 1705, 1683, 1713, 1713, 1609, 1707, 1724, 1707, 1734, 1690, 1713, 1666, 1656, 1632, 1697, 1697, 1697, 1677, 1639, 1651, 1656, 1654, 1651, 1614, 1621, 1627, 1603, 1558, 1606, 1599, 1532, 1384, 1549, 1571, 1555, 1560, 1535, 1546, 1516, 1521, 1510, 1508, 1498, 1492, 1479, 1455, 1467, 1461, 1448, 1448, 1436, 1416, 1425, 1386, 1388, 1415, 1400, 1384, 1385, 1373, 1366, 1354, 1328, 1331, 1348, 1350, 1346, 1319, 1326, 1318, 1309, 1307, 1278, 1258, 1286, 1279, 1283, 1270, 1262, 1259, 1255, 1248, 1240, 1237, 1241, 1221, 1185, 1203, 1204, 1208, 1188, 1196, 1187, 1187, 1176, 1180, 1177, 1174, 1158, 1143, 1134, 1152, 1135, 1142, 1129, 1115, 1120, 1095, 1114, 1115, 1107, 1104, 1063, 1080, 1073, 1075, 1080, 1081, 1063, 1051, 1041, 1052, 1044, 1040, 1036, 1024, 1028, 1023, 966, 996.1, 878, 975.5, 1005, 996.9, 994.9, 999.3, 886.2, 939.5, 974.7, 983.3, 971.3, 964, 974.9, 955.4, 951.1, 957.9, 938.3, 944.3, 953, 939.4, 933.2, 938.7, 933.9, 915.8, 891.6, 928.5, 917.6, 902.5, 891.6, 896.7, 907.1, 900.4, 895.1, 890.8, 863, 858.5, 861.2, 876.9, 867.7, 865.1, 864.1, 854.7, 858, 843.8, 825, 832.4, 837.5, 840.7, 836.9, 831.7, 808, 808.2, 818.8, 815.1, 808.9, 801.3, 794.7, 796.9, 795.9, 793.6, 781.5, 782.5, 777.9, 774.6, 776.4, 769.8, 766.1, 761.5, 754.1, 756.7, 755.6, 752.5, 751, 747.9, 746.9, 726.1, 713.6, 733.5, 731.3, 726.2, 721, 713.9, 710.7, 704.1, 702.1, 705.4, 702.7, 698.9, 693.7, 690.5, 681.7, 684, 677.2, 676.1, 674.6, 671.4, 660, 664.4, 662.2, 658.6, 654.9, 655.7, 645.1, 641.5, 643.8, 645.9, 639.5, 631.7, 624.1, 632.6, 627.6, 628, 627.2, 624.7, 609.9, 618, 620.8, 610.3, 619.9, 615.9, 584.9, 598.3, 596.1, 604.2, 593.2, 597.4, 594.5, 591.6, 590.6, 584.3, 584.4, 583.1, 581.5, 574.1, 579.6, 576.9, 565.5, 570, 565.3, 567.8, 563.8, 565.8, 556.9, 553, 553.1, 551.4, 554.8, 552.5, 548.9, 545.8, 547.9, 545.5, 543.5, 532, 532.5, 533.2, 530.3, 531.2, 527.6, 531.5, 527.3, 518.4, 519, 523.9, 515.9, 510.3, 518.7, 507.5, 508.5, 516.1, 514.5, 508.4, 494.3, 500.3, 506.8, 494.8, 503.9, 489, 488.2, 493.3, 494.2, 493, 489.7, 487.5, 485.4, 484.6, 481.7, 477.1, 479.2, 475, 472.9, 471.9, 470.3, 465.3, 464.2, 461.9, 463.5, 463.3, 462.4, 457.1, 457.4, 455.1, 453.3, 453, 449.7, 447.8, 446.7, 441.7, 445.3, 445.2, 443.1, 445.1, 444, 435.6, 401.4, 425.9, 432.8, 431.4, 425.5, 425.4, 422.3, 422.4, 418.4, 418.6, 413.9, 411.1, 413.6, 412.3, 410.6, 403.3, 402.2, 397.9, 401.7, 401.6, 398.6, 398.1, 394.9, 390.8, 387.8, 386.3, 389.2, 386.6, 383.2, 379, 380.5, 379.8, 377.2, 376.6, 372.4, 374.2, 372.2, 367.5, 368.8, 367.3, 367.7, 365.7, 365.7, 362.8, 359.9, 362.1, 361.1, 356.1, 358, 357.9, 354.5, 354.7, 353.2, 353, 350.6, 351.3, 348.8, 348.7, 349.2, 342.7, 343.9, 342.8, 343.1, 342.7, 341.8, 334.8, 337.7, 338.5, 338.6, 335.7, 331.5, 331.1, 328.1, 328.5, 325.7, 330, 328.4, 328.5, 328.3, 318.8, 318.6, 319.7, 321.6, 321.6, 318.7, 315.4, 314.3, 313.1, 316.7, 315.6, 312.1, 310.5, 310.8, 311.4, 310.2, 307.3, 303.4, 304.8, 304.4, 306.8, 304.4, 303.9, 303.3, 285.5, 301.5, 301.8, 303.3, 297.2, 299.4, 301.1, 292.4, 279.9, 284.8, 291.9, 294.7, 291.3, 288.3, 288.2, 288.4, 286.6, 282.4, 283.5, 284.6, 284.6, 276.5, 282.3, 278.4, 280.6, 277.3, 273, 275.3, 277.8, 277.2, 271.1, 271.3, 273.1, 267.6, 267.1, 268.9, 268.3, 269.7, 266.9, 265.4, 263.3, 264.5, 267.3, 261, 253.6, 254.7, 265, 259, 259.1, 259.9, 249, 240.5, 252.6, 258.3, 250.6, 254.5, 251.2, 248.9, 249.7, 247.7, 249.1, 240, 243, 244.9, 237.4, 242.3, 236.9, 238.3, 241.6, 240.2, 241.8, 239.3, 238.7, 235.9, 235.7, 227.4, 226.2, 226.6, 227.8, 229.4, 229.2, 227.2, 226.8, 226.2, 226, 225.2, 224.5, 224.6, 222.7, 221.2, 219.3, 222.5, 217.3, 219.3, 216.1, 216.8, 208, 205.4, 212.9, 213.1, 212, 210.5, 212.3, 211.2, 210, 208.9, 206.3, 204.7, 205.2, 205, 201.7, 201.3, 198.2, 203.7, 202.2, 201, 199.3, 197.5, 195.4, 198.2, 197.1, 198.4, 193.6, 187.4, 182.7, 186.3, 190.5, 190.2, 190.7, 186.7, 187.2, 185.8, 185, 185.6, 184.9, 184.3, 183.1, 179.3, 180.7, 181.7, 180.2, 179.1, 179.4, 179.2, 176.3, 174.7, 175.6, 174.7, 173.5, 173.9, 174.7, 173.3, 172.1, 170.9, 170.6, 170.3, 169.9, 167.2, 168.8, 168.8, 168.5, 168.6, 167.5, 165.8, 160.5, 152, 159.6, 159.8, 162.4, 162.8, 161.1, 160.6, 159.3, 158.5, 158.1, 156.2, 156.2, 154, 154.1, 153.5, 151, 154.6, 153.4, 152.5, 150.9, 152.5, 150.3, 150.4, 150.9, 149.4, 149.2, 150.8, 147.3, 140.1, 129.9, 144.1, 146.2, 147.4, 146.4, 143.9, 145.3, 142.4, 140.8, 139.6, 137.3, 139, 139.7, 140.9, 138.6, 139, 137.7, 137.8, 135.4, 137, 136, 135.3, 133.3, 135, 134.1, 134.4, 132.2, 131.3, 130.8, 132, 132.8, 132.1, 129.9, 129.4, 120.3, 119.2, 127.1, 126.1, 125.5, 128.6, 127.6, 127.1, 126.1, 124, 122.2, 123.1, 124, 123.9, 121.3, 120.8, 122.4, 119.4, 119.6, 120.5, 119.7, 117.8, 119.5, 119.8, 118, 116.2, 117.3, 115.9, 117, 116.1, 114.8, 114.7, 115.4, 114.9, 114.5, 113.8, 113.7, 113.4, 111.6, 110.7, 111.6, 111.5, 110.7, 108.6, 109.8, 109.2, 108.3, 106.4, 107.8, 107.6, 107.6, 107.1, 106.3, 105.9, 104.7, 104.6, 104.6, 104, 102.8, 102.3, 100.5, 102.5, 101.9, 100.3, 100.4, 100.9, 100.6, 100, 98.78, 98.64, 97.72, 98.52, 98.35, 97.88, 95.67, 95.93, 95.8, 96.2, 96.06, 95.77, 95.59, 95.74, 95.13, 93.96, 94.52, 94.36, 93.31, 93.11, 92.75, 92.75, 91.89, 92.08, 92.25, 92.09, 92.1, 91.55, 90.12, 91.1, 90.83, 90.64, 90.06, 89.39, 89.79, 89.57, 89.13, 88.78, 88.74, 88.42, 87.81, 86.86, 84.56, 78.49, 83, 85.57, 85.91, 85.92, 85.32, 84.25, 84.97, 84.25, 84.57, 84.65, 82.77, 83.04, 83.77, 83.49, 83.18, 82.99, 82.65, 82.3, 82.11, 79.66, 79.66, 80.8, 81.05, 80.72, 79.94, 79.7, 79.97, 79.62, 79.26, 78.11, 78.26, 78.31, 78.15, 78.02, 77.58, 76.48, 76.39, 76.42, 76.24, 76.12, 75.2, 75.41, 75.12, 74.02, 74.22, 74.41, 74.21, 72.99, 73.29, 73.15, 73.27, 72.97, 72.77, 72.52, 72.39, 72.42, 71.65, 70.07, 71.25, 71.24, 71.27, 71.1, 70.67, 69.2, 69.08, 69.19, 69.53, 69.55, 69.31, 69.23, 69.01, 68.7, 68.67, 68.26, 67.79, 67.45, 67.68, 66.75, 65.36, 65.59, 66.29, 66.16, 65.84, 65.71, 65.36, 64.96, 65.2, 65.39, 65.09, 64.86, 64.72, 64.53, 62.89, 62.39, 62.82, 62.66, 63.08, 63.05, 62.95, 62.84, 62.63, 62.11, 62.07, 60.66, 61.64, 61.92, 61.72, 60.98, 58.85, 59.08, 60.04, 60.29, 60.08, 60.03, 59.96, 59.89, 59.44, 59.65, 59.45, 59.19, 59.15, 59.02, 58.94, 57.34, 55.99, 57.48, 57.7, 57.67, 57.26, 57.17, 57.12, 57.12, 57.02, 56.41, 56.18, 55.99, 56.39, 56.17, 56.03, 54.98, 54.57, 54.62, 54.32, 54.55, 53.7, 53.92, 54.57, 54.42, 54.35, 54.05, 53.9, 52.85, 53.3, 53.13, 53.43, 53.03, 51.77, 51.4, 52.19, 51.6, 51.69, 52.25, 51.98, 51.75, 51.52, 51.54, 51.55, 49.84, 48.14, 46.72, 45.5, 44.57, 43.05, 42.11, 40.79, 39.68, 38.67, 37.63, 36.63, 35.46, 34.68, 33.85, 32.97, 32.09, 31.19, 30.32, 29.69, 28.9, 28.17, 27.5, 26.82, 26.12, 25.47, 24.65, 24.22, 23.64, 23.06, 22.46, 21.98, 21.44, 20.96, 20.48, 20, 19.51, 19.07, 18.58, 18.02, 17.68, 17.37, 16.97, 16.59, 16.15, 15.84, 15.54, 15.2, 14.86, 14.56, 14.25, 13.93, 13.62, 13.34, 13.07, 12.81, 12.51, 12.22, 11.93, 11.62, 11.45, 11.08, 10.96, 10.78, 10.57, 10.38, 10.19, 9.983, 9.782, 9.599, 9.427, 9.233, 9.032, 8.857, 8.669, 8.557, 8.385, 8.217, 8.054, 7.894, 7.739, 7.587, 7.439, 7.294, 7.153, 7.015, 6.881, 6.749, 6.621, 6.496, 6.374, 6.254, 6.138, 6.024, 5.913, 5.804, 5.698, 5.594, 5.492, 5.393, 5.296, 5.201, 5.108, 5.018, 4.929, 4.842, 4.757, 4.674, 4.593, 4.514, 4.436, 4.36, 4.285, 4.212, 4.141, 4.071, 4.003, 3.936, 3.87, 3.806, 3.743, 3.681, 3.621, 3.562, 3.504, 3.394, 3.267, 3.146, 3.03, 2.92, 2.815, 2.715, 2.619, 2.527, 2.439, 2.355, 2.275, 2.198, 2.124, 2.054, 1.986, 1.921, 1.859, 1.799, 1.742, 1.687, 1.634, 1.583, 1.534, 1.487, 1.442, 1.399, 1.357, 1.317, 1.278, 1.24, 1.204, 1.17, 1.136, 1.104, 1.073, 1.043, 1.014, 0.9862, 0.9592, 0.9331, 0.908, 0.8836, 0.8601, 0.8374, 0.8154, 0.7942, 0.7736, 0.7537, 0.7344, 0.7158, 0.6977, 0.6802, 0.6633, 0.6469, 0.631, 0.6156, 0.6006, 0.5862, 0.5721, 0.5585, 0.5453, 0.5324, 0.52, 0.5079, 0.4961, 0.4847, 0.4737, 0.4629, 0.4525, 0.4423, 0.4324, 0.4228, 0.4135, 0.4044, 0.3956, 0.387, 0.3787, 0.3706, 0.3627, 0.355, 0.3475, 0.3402, 0.3331, 0.3262, 0.3195, 0.3129, 0.3065, 0.3003, 0.2942, 0.2883, 0.2825, 0.2769, 0.2714, 0.2661, 0.2608, 0.2558, 0.2508, 0.246, 0.2412, 0.1635, 0.1152, 8.34E-02, 6.19E-02, 4.69E-02, 3.61E-02, 2.83E-02, 2.25E-02, 1.81E-02, 1.47E-02, 6.05E-03, 2.93E-03, 1.58E-03, 9.31E-04, 3.83E-04, 1.85E-04, 5.88E-05, 2.42E-05, 1.17E-05, 4.81E-06, 1.53E-06, 6.28E-07, 2.95E-07, 1.01E-07, 3.38E-09 ]
	);

	// ASTM G-173, direct
	var AM15 = new EmData(
		[ 0.28, 0.2805, 0.281, 0.2815, 0.282, 0.2825, 0.283, 0.2835, 0.284, 0.2845, 0.285, 0.2855, 0.286, 0.2865, 0.287, 0.2875, 0.288, 0.2885, 0.289, 0.2895, 0.29, 0.2905, 0.291, 0.2915, 0.292, 0.2925, 0.293, 0.2935, 0.294, 0.2945, 0.295, 0.2955, 0.296, 0.2965, 0.297, 0.2975, 0.298, 0.2985, 0.299, 0.2995, 0.3, 0.3005, 0.301, 0.3015, 0.302, 0.3025, 0.303, 0.3035, 0.304, 0.3045, 0.305, 0.3055, 0.306, 0.3065, 0.307, 0.3075, 0.308, 0.3085, 0.309, 0.3095, 0.31, 0.3105, 0.311, 0.3115, 0.312, 0.3125, 0.313, 0.3135, 0.314, 0.3145, 0.315, 0.3155, 0.316, 0.3165, 0.317, 0.3175, 0.318, 0.3185, 0.319, 0.3195, 0.32, 0.3205, 0.321, 0.3215, 0.322, 0.3225, 0.323, 0.3235, 0.324, 0.3245, 0.325, 0.3255, 0.326, 0.3265, 0.327, 0.3275, 0.328, 0.3285, 0.329, 0.3295, 0.33, 0.3305, 0.331, 0.3315, 0.332, 0.3325, 0.333, 0.3335, 0.334, 0.3345, 0.335, 0.3355, 0.336, 0.3365, 0.337, 0.3375, 0.338, 0.3385, 0.339, 0.3395, 0.34, 0.3405, 0.341, 0.3415, 0.342, 0.3425, 0.343, 0.3435, 0.344, 0.3445, 0.345, 0.3455, 0.346, 0.3465, 0.347, 0.3475, 0.348, 0.3485, 0.349, 0.3495, 0.35, 0.3505, 0.351, 0.3515, 0.352, 0.3525, 0.353, 0.3535, 0.354, 0.3545, 0.355, 0.3555, 0.356, 0.3565, 0.357, 0.3575, 0.358, 0.3585, 0.359, 0.3595, 0.36, 0.3605, 0.361, 0.3615, 0.362, 0.3625, 0.363, 0.3635, 0.364, 0.3645, 0.365, 0.3655, 0.366, 0.3665, 0.367, 0.3675, 0.368, 0.3685, 0.369, 0.3695, 0.37, 0.3705, 0.371, 0.3715, 0.372, 0.3725, 0.373, 0.3735, 0.374, 0.3745, 0.375, 0.3755, 0.376, 0.3765, 0.377, 0.3775, 0.378, 0.3785, 0.379, 0.3795, 0.38, 0.3805, 0.381, 0.3815, 0.382, 0.3825, 0.383, 0.3835, 0.384, 0.3845, 0.385, 0.3855, 0.386, 0.3865, 0.387, 0.3875, 0.388, 0.3885, 0.389, 0.3895, 0.39, 0.3905, 0.391, 0.3915, 0.392, 0.3925, 0.393, 0.3935, 0.394, 0.3945, 0.395, 0.3955, 0.396, 0.3965, 0.397, 0.3975, 0.398, 0.3985, 0.399, 0.3995, 0.4, 0.401, 0.402, 0.403, 0.404, 0.405, 0.406, 0.407, 0.408, 0.409, 0.41, 0.411, 0.412, 0.413, 0.414, 0.415, 0.416, 0.417, 0.418, 0.419, 0.42, 0.421, 0.422, 0.423, 0.424, 0.425, 0.426, 0.427, 0.428, 0.429, 0.43, 0.431, 0.432, 0.433, 0.434, 0.435, 0.436, 0.437, 0.438, 0.439, 0.44, 0.441, 0.442, 0.443, 0.444, 0.445, 0.446, 0.447, 0.448, 0.449, 0.45, 0.451, 0.452, 0.453, 0.454, 0.455, 0.456, 0.457, 0.458, 0.459, 0.46, 0.461, 0.462, 0.463, 0.464, 0.465, 0.466, 0.467, 0.468, 0.469, 0.47, 0.471, 0.472, 0.473, 0.474, 0.475, 0.476, 0.477, 0.478, 0.479, 0.48, 0.481, 0.482, 0.483, 0.484, 0.485, 0.486, 0.487, 0.488, 0.489, 0.49, 0.491, 0.492, 0.493, 0.494, 0.495, 0.496, 0.497, 0.498, 0.499, 0.5, 0.501, 0.502, 0.503, 0.504, 0.505, 0.506, 0.507, 0.508, 0.509, 0.51, 0.511, 0.512, 0.513, 0.514, 0.515, 0.516, 0.517, 0.518, 0.519, 0.52, 0.521, 0.522, 0.523, 0.524, 0.525, 0.526, 0.527, 0.528, 0.529, 0.53, 0.531, 0.532, 0.533, 0.534, 0.535, 0.536, 0.537, 0.538, 0.539, 0.54, 0.541, 0.542, 0.543, 0.544, 0.545, 0.546, 0.547, 0.548, 0.549, 0.55, 0.551, 0.552, 0.553, 0.554, 0.555, 0.556, 0.557, 0.558, 0.559, 0.56, 0.561, 0.562, 0.563, 0.564, 0.565, 0.566, 0.567, 0.568, 0.569, 0.57, 0.571, 0.572, 0.573, 0.574, 0.575, 0.576, 0.577, 0.578, 0.579, 0.58, 0.581, 0.582, 0.583, 0.584, 0.585, 0.586, 0.587, 0.588, 0.589, 0.59, 0.591, 0.592, 0.593, 0.594, 0.595, 0.596, 0.597, 0.598, 0.599, 0.6, 0.601, 0.602, 0.603, 0.604, 0.605, 0.606, 0.607, 0.608, 0.609, 0.61, 0.611, 0.612, 0.613, 0.614, 0.615, 0.616, 0.617, 0.618, 0.619, 0.62, 0.621, 0.622, 0.623, 0.624, 0.625, 0.626, 0.627, 0.628, 0.629, 0.63, 0.631, 0.632, 0.633, 0.634, 0.635, 0.636, 0.637, 0.638, 0.639, 0.64, 0.641, 0.642, 0.643, 0.644, 0.645, 0.646, 0.647, 0.648, 0.649, 0.65, 0.651, 0.652, 0.653, 0.654, 0.655, 0.656, 0.657, 0.658, 0.659, 0.66, 0.661, 0.662, 0.663, 0.664, 0.665, 0.666, 0.667, 0.668, 0.669, 0.67, 0.671, 0.672, 0.673, 0.674, 0.675, 0.676, 0.677, 0.678, 0.679, 0.68, 0.681, 0.682, 0.683, 0.684, 0.685, 0.686, 0.687, 0.688, 0.689, 0.69, 0.691, 0.692, 0.693, 0.694, 0.695, 0.696, 0.697, 0.698, 0.699, 0.7, 0.701, 0.702, 0.703, 0.704, 0.705, 0.706, 0.707, 0.708, 0.709, 0.71, 0.711, 0.712, 0.713, 0.714, 0.715, 0.716, 0.717, 0.718, 0.719, 0.72, 0.721, 0.722, 0.723, 0.724, 0.725, 0.726, 0.727, 0.728, 0.729, 0.73, 0.731, 0.732, 0.733, 0.734, 0.735, 0.736, 0.737, 0.738, 0.739, 0.74, 0.741, 0.742, 0.743, 0.744, 0.745, 0.746, 0.747, 0.748, 0.749, 0.75, 0.751, 0.752, 0.753, 0.754, 0.755, 0.756, 0.757, 0.758, 0.759, 0.76, 0.761, 0.762, 0.763, 0.764, 0.765, 0.766, 0.767, 0.768, 0.769, 0.77, 0.771, 0.772, 0.773, 0.774, 0.775, 0.776, 0.777, 0.778, 0.779, 0.78, 0.781, 0.782, 0.783, 0.784, 0.785, 0.786, 0.787, 0.788, 0.789, 0.79, 0.791, 0.792, 0.793, 0.794, 0.795, 0.796, 0.797, 0.798, 0.799, 0.8, 0.801, 0.802, 0.803, 0.804, 0.805, 0.806, 0.807, 0.808, 0.809, 0.81, 0.811, 0.812, 0.813, 0.814, 0.815, 0.816, 0.817, 0.818, 0.819, 0.82, 0.821, 0.822, 0.823, 0.824, 0.825, 0.826, 0.827, 0.828, 0.829, 0.83, 0.831, 0.832, 0.833, 0.834, 0.835, 0.836, 0.837, 0.838, 0.839, 0.84, 0.841, 0.842, 0.843, 0.844, 0.845, 0.846, 0.847, 0.848, 0.849, 0.85, 0.851, 0.852, 0.853, 0.854, 0.855, 0.856, 0.857, 0.858, 0.859, 0.86, 0.861, 0.862, 0.863, 0.864, 0.865, 0.866, 0.867, 0.868, 0.869, 0.87, 0.871, 0.872, 0.873, 0.874, 0.875, 0.876, 0.877, 0.878, 0.879, 0.88, 0.881, 0.882, 0.883, 0.884, 0.885, 0.886, 0.887, 0.888, 0.889, 0.89, 0.891, 0.892, 0.893, 0.894, 0.895, 0.896, 0.897, 0.898, 0.899, 0.9, 0.901, 0.902, 0.903, 0.904, 0.905, 0.906, 0.907, 0.908, 0.909, 0.91, 0.911, 0.912, 0.913, 0.914, 0.915, 0.916, 0.917, 0.918, 0.919, 0.92, 0.921, 0.922, 0.923, 0.924, 0.925, 0.926, 0.927, 0.928, 0.929, 0.93, 0.931, 0.932, 0.933, 0.934, 0.935, 0.936, 0.937, 0.938, 0.939, 0.94, 0.941, 0.942, 0.943, 0.944, 0.945, 0.946, 0.947, 0.948, 0.949, 0.95, 0.951, 0.952, 0.953, 0.954, 0.955, 0.956, 0.957, 0.958, 0.959, 0.96, 0.961, 0.962, 0.963, 0.964, 0.965, 0.966, 0.967, 0.968, 0.969, 0.97, 0.971, 0.972, 0.973, 0.974, 0.975, 0.976, 0.977, 0.978, 0.979, 0.98, 0.981, 0.982, 0.983, 0.984, 0.985, 0.986, 0.987, 0.988, 0.989, 0.99, 0.991, 0.992, 0.993, 0.994, 0.995, 0.996, 0.997, 0.998, 0.999, 1, 1.001, 1.002, 1.003, 1.004, 1.005, 1.006, 1.007, 1.008, 1.009, 1.01, 1.011, 1.012, 1.013, 1.014, 1.015, 1.016, 1.017, 1.018, 1.019, 1.02, 1.021, 1.022, 1.023, 1.024, 1.025, 1.026, 1.027, 1.028, 1.029, 1.03, 1.031, 1.032, 1.033, 1.034, 1.035, 1.036, 1.037, 1.038, 1.039, 1.04, 1.041, 1.042, 1.043, 1.044, 1.045, 1.046, 1.047, 1.048, 1.049, 1.05, 1.051, 1.052, 1.053, 1.054, 1.055, 1.056, 1.057, 1.058, 1.059, 1.06, 1.061, 1.062, 1.063, 1.064, 1.065, 1.066, 1.067, 1.068, 1.069, 1.07, 1.071, 1.072, 1.073, 1.074, 1.075, 1.076, 1.077, 1.078, 1.079, 1.08, 1.081, 1.082, 1.083, 1.084, 1.085, 1.086, 1.087, 1.088, 1.089, 1.09, 1.091, 1.092, 1.093, 1.094, 1.095, 1.096, 1.097, 1.098, 1.099, 1.1, 1.101, 1.102, 1.103, 1.104, 1.105, 1.106, 1.107, 1.108, 1.109, 1.11, 1.111, 1.112, 1.113, 1.114, 1.115, 1.116, 1.117, 1.118, 1.119, 1.12, 1.121, 1.122, 1.123, 1.124, 1.125, 1.126, 1.127, 1.128, 1.129, 1.13, 1.131, 1.132, 1.133, 1.134, 1.135, 1.136, 1.137, 1.138, 1.139, 1.14, 1.141, 1.142, 1.143, 1.144, 1.145, 1.146, 1.147, 1.148, 1.149, 1.15, 1.151, 1.152, 1.153, 1.154, 1.155, 1.156, 1.157, 1.158, 1.159, 1.16, 1.161, 1.162, 1.163, 1.164, 1.165, 1.166, 1.167, 1.168, 1.169, 1.17, 1.171, 1.172, 1.173, 1.174, 1.175, 1.176, 1.177, 1.178, 1.179, 1.18, 1.181, 1.182, 1.183, 1.184, 1.185, 1.186, 1.187, 1.188, 1.189, 1.19, 1.191, 1.192, 1.193, 1.194, 1.195, 1.196, 1.197, 1.198, 1.199, 1.2, 1.201, 1.202, 1.203, 1.204, 1.205, 1.206, 1.207, 1.208, 1.209, 1.21, 1.211, 1.212, 1.213, 1.214, 1.215, 1.216, 1.217, 1.218, 1.219, 1.22, 1.221, 1.222, 1.223, 1.224, 1.225, 1.226, 1.227, 1.228, 1.229, 1.23, 1.231, 1.232, 1.233, 1.234, 1.235, 1.236, 1.237, 1.238, 1.239, 1.24, 1.241, 1.242, 1.243, 1.244, 1.245, 1.246, 1.247, 1.248, 1.249, 1.25, 1.251, 1.252, 1.253, 1.254, 1.255, 1.256, 1.257, 1.258, 1.259, 1.26, 1.261, 1.262, 1.263, 1.264, 1.265, 1.266, 1.267, 1.268, 1.269, 1.27, 1.271, 1.272, 1.273, 1.274, 1.275, 1.276, 1.277, 1.278, 1.279, 1.28, 1.281, 1.282, 1.283, 1.284, 1.285, 1.286, 1.287, 1.288, 1.289, 1.29, 1.291, 1.292, 1.293, 1.294, 1.295, 1.296, 1.297, 1.298, 1.299, 1.3, 1.301, 1.302, 1.303, 1.304, 1.305, 1.306, 1.307, 1.308, 1.309, 1.31, 1.311, 1.312, 1.313, 1.314, 1.315, 1.316, 1.317, 1.318, 1.319, 1.32, 1.321, 1.322, 1.323, 1.324, 1.325, 1.326, 1.327, 1.328, 1.329, 1.33, 1.331, 1.332, 1.333, 1.334, 1.335, 1.336, 1.337, 1.338, 1.339, 1.34, 1.341, 1.342, 1.343, 1.344, 1.345, 1.346, 1.347, 1.348, 1.349, 1.35, 1.351, 1.352, 1.353, 1.354, 1.355, 1.356, 1.357, 1.358, 1.359, 1.36, 1.361, 1.362, 1.363, 1.364, 1.365, 1.366, 1.367, 1.368, 1.369, 1.37, 1.371, 1.372, 1.373, 1.374, 1.375, 1.376, 1.377, 1.378, 1.379, 1.38, 1.381, 1.382, 1.383, 1.384, 1.385, 1.386, 1.387, 1.388, 1.389, 1.39, 1.391, 1.392, 1.393, 1.394, 1.395, 1.396, 1.397, 1.398, 1.399, 1.4, 1.401, 1.402, 1.403, 1.404, 1.405, 1.406, 1.407, 1.408, 1.409, 1.41, 1.411, 1.412, 1.413, 1.414, 1.415, 1.416, 1.417, 1.418, 1.419, 1.42, 1.421, 1.422, 1.423, 1.424, 1.425, 1.426, 1.427, 1.428, 1.429, 1.43, 1.431, 1.432, 1.433, 1.434, 1.435, 1.436, 1.437, 1.438, 1.439, 1.44, 1.441, 1.442, 1.443, 1.444, 1.445, 1.446, 1.447, 1.448, 1.449, 1.45, 1.451, 1.452, 1.453, 1.454, 1.455, 1.456, 1.457, 1.458, 1.459, 1.46, 1.461, 1.462, 1.463, 1.464, 1.465, 1.466, 1.467, 1.468, 1.469, 1.47, 1.471, 1.472, 1.473, 1.474, 1.475, 1.476, 1.477, 1.478, 1.479, 1.48, 1.481, 1.482, 1.483, 1.484, 1.485, 1.486, 1.487, 1.488, 1.489, 1.49, 1.491, 1.492, 1.493, 1.494, 1.495, 1.496, 1.497, 1.498, 1.499, 1.5, 1.501, 1.502, 1.503, 1.504, 1.505, 1.506, 1.507, 1.508, 1.509, 1.51, 1.511, 1.512, 1.513, 1.514, 1.515, 1.516, 1.517, 1.518, 1.519, 1.52, 1.521, 1.522, 1.523, 1.524, 1.525, 1.526, 1.527, 1.528, 1.529, 1.53, 1.531, 1.532, 1.533, 1.534, 1.535, 1.536, 1.537, 1.538, 1.539, 1.54, 1.541, 1.542, 1.543, 1.544, 1.545, 1.546, 1.547, 1.548, 1.549, 1.55, 1.551, 1.552, 1.553, 1.554, 1.555, 1.556, 1.557, 1.558, 1.559, 1.56, 1.561, 1.562, 1.563, 1.564, 1.565, 1.566, 1.567, 1.568, 1.569, 1.57, 1.571, 1.572, 1.573, 1.574, 1.575, 1.576, 1.577, 1.578, 1.579, 1.58, 1.581, 1.582, 1.583, 1.584, 1.585, 1.586, 1.587, 1.588, 1.589, 1.59, 1.591, 1.592, 1.593, 1.594, 1.595, 1.596, 1.597, 1.598, 1.599, 1.6, 1.601, 1.602, 1.603, 1.604, 1.605, 1.606, 1.607, 1.608, 1.609, 1.61, 1.611, 1.612, 1.613, 1.614, 1.615, 1.616, 1.617, 1.618, 1.619, 1.62, 1.621, 1.622, 1.623, 1.624, 1.625, 1.626, 1.627, 1.628, 1.629, 1.63, 1.631, 1.632, 1.633, 1.634, 1.635, 1.636, 1.637, 1.638, 1.639, 1.64, 1.641, 1.642, 1.643, 1.644, 1.645, 1.646, 1.647, 1.648, 1.649, 1.65, 1.651, 1.652, 1.653, 1.654, 1.655, 1.656, 1.657, 1.658, 1.659, 1.66, 1.661, 1.662, 1.663, 1.664, 1.665, 1.666, 1.667, 1.668, 1.669, 1.67, 1.671, 1.672, 1.673, 1.674, 1.675, 1.676, 1.677, 1.678, 1.679, 1.68, 1.681, 1.682, 1.683, 1.684, 1.685, 1.686, 1.687, 1.688, 1.689, 1.69, 1.691, 1.692, 1.693, 1.694, 1.695, 1.696, 1.697, 1.698, 1.699, 1.7, 1.702, 1.705, 1.71, 1.715, 1.72, 1.725, 1.73, 1.735, 1.74, 1.745, 1.75, 1.755, 1.76, 1.765, 1.77, 1.775, 1.78, 1.785, 1.79, 1.795, 1.8, 1.805, 1.81, 1.815, 1.82, 1.825, 1.83, 1.835, 1.84, 1.845, 1.85, 1.855, 1.86, 1.865, 1.87, 1.875, 1.88, 1.885, 1.89, 1.895, 1.9, 1.905, 1.91, 1.915, 1.92, 1.925, 1.93, 1.935, 1.94, 1.945, 1.95, 1.955, 1.96, 1.965, 1.97, 1.975, 1.98, 1.985, 1.99, 1.995, 2, 2.005, 2.01, 2.015, 2.02, 2.025, 2.03, 2.035, 2.04, 2.045, 2.05, 2.055, 2.06, 2.065, 2.07, 2.075, 2.08, 2.085, 2.09, 2.095, 2.1, 2.105, 2.11, 2.115, 2.12, 2.125, 2.13, 2.135, 2.14, 2.145, 2.15, 2.155, 2.16, 2.165, 2.17, 2.175, 2.18, 2.185, 2.19, 2.195, 2.2, 2.205, 2.21, 2.215, 2.22, 2.225, 2.23, 2.235, 2.24, 2.245, 2.25, 2.255, 2.26, 2.265, 2.27, 2.275, 2.28, 2.285, 2.29, 2.295, 2.3, 2.305, 2.31, 2.315, 2.32, 2.325, 2.33, 2.335, 2.34, 2.345, 2.35, 2.355, 2.36, 2.365, 2.37, 2.375, 2.38, 2.385, 2.39, 2.395, 2.4, 2.405, 2.41, 2.415, 2.42, 2.425, 2.43, 2.435, 2.44, 2.445, 2.45, 2.455, 2.46, 2.465, 2.47, 2.475, 2.48, 2.485, 2.49, 2.495, 2.5, 2.505, 2.51, 2.515, 2.52, 2.525, 2.53, 2.535, 2.54, 2.545, 2.55, 2.555, 2.56, 2.565, 2.57, 2.575, 2.58, 2.585, 2.59, 2.595, 2.6, 2.605, 2.61, 2.615, 2.62, 2.625, 2.63, 2.635, 2.64, 2.645, 2.65, 2.655, 2.66, 2.665, 2.67, 2.675, 2.68, 2.685, 2.69, 2.695, 2.7, 2.705, 2.71, 2.715, 2.72, 2.725, 2.73, 2.735, 2.74, 2.745, 2.75, 2.755, 2.76, 2.765, 2.77, 2.775, 2.78, 2.785, 2.79, 2.795, 2.8, 2.805, 2.81, 2.815, 2.82, 2.825, 2.83, 2.835, 2.84, 2.845, 2.85, 2.855, 2.86, 2.865, 2.87, 2.875, 2.88, 2.885, 2.89, 2.895, 2.9, 2.905, 2.91, 2.915, 2.92, 2.925, 2.93, 2.935, 2.94, 2.945, 2.95, 2.955, 2.96, 2.965, 2.97, 2.975, 2.98, 2.985, 2.99, 2.995, 3, 3.005, 3.01, 3.015, 3.02, 3.025, 3.03, 3.035, 3.04, 3.045, 3.05, 3.055, 3.06, 3.065, 3.07, 3.075, 3.08, 3.085, 3.09, 3.095, 3.1, 3.105, 3.11, 3.115, 3.12, 3.125, 3.13, 3.135, 3.14, 3.145, 3.15, 3.155, 3.16, 3.165, 3.17, 3.175, 3.18, 3.185, 3.19, 3.195, 3.2, 3.205, 3.21, 3.215, 3.22, 3.225, 3.23, 3.235, 3.24, 3.245, 3.25, 3.255, 3.26, 3.265, 3.27, 3.275, 3.28, 3.285, 3.29, 3.295, 3.3, 3.305, 3.31, 3.315, 3.32, 3.325, 3.33, 3.335, 3.34, 3.345, 3.35, 3.355, 3.36, 3.365, 3.37, 3.375, 3.38, 3.385, 3.39, 3.395, 3.4, 3.405, 3.41, 3.415, 3.42, 3.425, 3.43, 3.435, 3.44, 3.445, 3.45, 3.455, 3.46, 3.465, 3.47, 3.475, 3.48, 3.485, 3.49, 3.495, 3.5, 3.505, 3.51, 3.515, 3.52, 3.525, 3.53, 3.535, 3.54, 3.545, 3.55, 3.555, 3.56, 3.565, 3.57, 3.575, 3.58, 3.585, 3.59, 3.595, 3.6, 3.605, 3.61, 3.615, 3.62, 3.625, 3.63, 3.635, 3.64, 3.645, 3.65, 3.655, 3.66, 3.665, 3.67, 3.675, 3.68, 3.685, 3.69, 3.695, 3.7, 3.705, 3.71, 3.715, 3.72, 3.725, 3.73, 3.735, 3.74, 3.745, 3.75, 3.755, 3.76, 3.765, 3.77, 3.775, 3.78, 3.785, 3.79, 3.795, 3.8, 3.805, 3.81, 3.815, 3.82, 3.825, 3.83, 3.835, 3.84, 3.845, 3.85, 3.855, 3.86, 3.865, 3.87, 3.875, 3.88, 3.885, 3.89, 3.895, 3.9, 3.905, 3.91, 3.915, 3.92, 3.925, 3.93, 3.935, 3.94, 3.945, 3.95, 3.955, 3.96, 3.965, 3.97, 3.975, 3.98, 3.985, 3.99, 3.995, 4 ],
		[ 2.5361E-23, 1.0917E-21, 6.1253E-21, 2.7479E-19, 2.8346E-18, 1.3271E-17, 6.7646E-17, 1.4614E-16, 4.9838E-15, 2.1624E-14, 8.9998E-14, 6.4424E-13, 2.3503E-12, 1.8458E-11, 7.2547E-11, 3.6618E-10, 2.8061E-9, 9.0651E-9, 3.4978E-8, 1.5368E-7, 5.1454E-7, 1.3303E-6, 3.8965E-6, 1.4425E-5, 4.0789E-5, 7.0414E-5, 1.576E-4, 4.7095E-4, 9.4558E-4, 0.0016, 0.00322, 0.00802, 0.01474, 0.02331, 0.03319, 0.06791, 0.11127, 0.1427, 0.20323, 0.37386, 0.45631, 0.57207, 0.91926, 1.3201, 1.457, 2.191, 3.7332, 4.8044, 5.0973, 6.4675, 8.9336, 10.186, 10.15, 11.568, 15.246, 19.468, 20.753, 22.75, 22.298, 23.672, 27.826, 35.879, 45.392, 46.156, 50.898, 53.766, 58.323, 58.999, 65.266, 70.476, 73.686, 64.833, 67.088, 81.118, 93.02, 99.712, 95.815, 100.05, 109.71, 106.93, 112.77, 133.05, 134.14, 128.17, 122, 119.7, 116.23, 133.93, 148.52, 154.67, 155.04, 179.36, 208.68, 221.62, 218.34, 212.85, 197.73, 206.75, 232.97, 258.64, 261.92, 241.03, 228.35, 236.35, 245.08, 246.55, 242.63, 232.65, 238.23, 254.34, 264.77, 258.94, 238.13, 220.99, 217.67, 234.34, 253.21, 265.49, 270.96, 278.47, 296.59, 296.74, 279.32, 278.53, 291.21, 302.96, 308.57, 292.46, 253.52, 244.39, 278.54, 297.61, 291.32, 297.47, 303.18, 293.51, 293.06, 298.84, 288.64, 297.2, 329.13, 354.71, 346.03, 333.88, 326.74, 309.54, 329.75, 363.51, 385.23, 390.43, 391.4, 378.78, 356.27, 334.95, 295.27, 299.5, 279.36, 259.98, 306.5, 370.13, 392.4, 371.67, 342.78, 336.47, 353.5, 388.04, 400.05, 389.94, 404.72, 401.79, 418.1, 461.1, 495.08, 496.94, 488.69, 480.41, 453.19, 451.06, 472.44, 508.56, 516.66, 467.98, 476.28, 495.87, 465.06, 443.89, 428.33, 386.82, 386.51, 384.35, 410.87, 455.14, 472.18, 465.38, 500.14, 558.9, 603.14, 588.92, 526.16, 472.55, 497.51, 533.96, 544.24, 491.35, 419.58, 363.61, 326.48, 316.58, 366.89, 442.39, 486.38, 465.49, 449.84, 468.48, 473.43, 467.31, 463.5, 460.96, 501.21, 556.37, 584.57, 590.38, 626.34, 636.17, 586.56, 489.61, 355.02, 282.72, 367.8, 508.11, 600.96, 641.01, 564.43, 411.01, 318.82, 471.51, 639.44, 756.22, 804.08, 829.8, 839.89, 876.91, 913.87, 882.11, 898.49, 878.49, 858.78, 845.45, 884.88, 947.17, 809.1, 907.7, 966.86, 929.51, 921.34, 955.69, 986.28, 963.92, 923.92, 963.54, 884.67, 1006.7, 994.99, 965.31, 961.82, 993.12, 966.67, 935.5, 946.25, 877.66, 701.34, 637.79, 1062.8, 990.5, 916.53, 1007, 1106.1, 1130.6, 993.68, 957.53, 1099.3, 1085.9, 1164, 1182.3, 1153.7, 1199.2, 1076.6, 1225.7, 1242.2, 1240.9, 1288.1, 1337.6, 1282.2, 1185.4, 1273, 1265.5, 1308.8, 1321.3, 1294.6, 1285.9, 1279.1, 1325.5, 1339.2, 1345.2, 1305.5, 1290.5, 1319, 1261.6, 1317.8, 1324.7, 1274.9, 1297.5, 1366.1, 1314.4, 1330.4, 1375.5, 1329.9, 1339.2, 1383.9, 1358.6, 1382.5, 1383.6, 1389.9, 1374.2, 1349.2, 1345.7, 1091.8, 1223.5, 1325.2, 1249.2, 1396.8, 1343.5, 1281.8, 1371.9, 1340.2, 1423.8, 1354.8, 1378.8, 1342.1, 1342.9, 1339.1, 1299, 1299.1, 1359.7, 1268.2, 1359.8, 1415.3, 1354.8, 1321, 1385, 1349.7, 1375.3, 1412.5, 1327.7, 1300.3, 1338.5, 1351.4, 1101.7, 1260.5, 1222.2, 1334.9, 1345.2, 1376, 1297.6, 1396.2, 1385.9, 1347.9, 1179.5, 1350.8, 1414.2, 1359.8, 1434.8, 1409.4, 1259, 1349.1, 1370.1, 1429.2, 1322.9, 1389.6, 1355.8, 1309.6, 1259.5, 1371.4, 1349.3, 1397.1, 1365.7, 1353.6, 1371.7, 1333.1, 1375.2, 1364.8, 1363.9, 1392.3, 1353.3, 1380.2, 1388.3, 1365.1, 1332.1, 1361.3, 1288.5, 1311.8, 1388.5, 1322.5, 1373.1, 1346.6, 1355.5, 1282.3, 1367.3, 1355.4, 1322.8, 1324, 1281, 1353.4, 1359.5, 1352.7, 1322.5, 1311.8, 1345.2, 1304, 1323, 1345.5, 1351.8, 1372.9, 1387.2, 1384.5, 1373.7, 1340.9, 1370.8, 1340.3, 1158.2, 1231.6, 1317.1, 1290, 1308.6, 1302.9, 1287, 1326, 1330.3, 1314.2, 1314.5, 1327.8, 1312.3, 1292.8, 1320.5, 1343.9, 1341.8, 1335.3, 1343.4, 1339.2, 1329.2, 1323.7, 1317, 1337, 1318.2, 1278.3, 1325.4, 1290.6, 1274.4, 1322.8, 1329.2, 1329.9, 1335.9, 1288.2, 1279.3, 1275.1, 1266.7, 1265.5, 1302.2, 1232.8, 1275.8, 1258.9, 1279.9, 1232.7, 1311, 1290.7, 1306.5, 1276.8, 1320.4, 1329.2, 1323.8, 1296.2, 1297, 1299.5, 1313, 1307.4, 1317, 1279.7, 1274.4, 1262.5, 1223.4, 1229.9, 1307.1, 1255.8, 1295, 1280.7, 1222, 1072.7, 1121.8, 1254, 1258.6, 1266.8, 1261.8, 1251.8, 1253.9, 1264.7, 1287.1, 1286, 1276.7, 1281, 1303.2, 1285.3, 1282.9, 1265.1, 1276, 1274.2, 1263.9, 1278.6, 1266.9, 1273.7, 1262.9, 1265, 1260.1, 1266.2, 1252.6, 1244.5, 1245.4, 1217.4, 882.85, 1019.5, 1026, 1074.6, 1120.1, 1151.6, 1144.6, 1131.8, 1153.8, 1151.3, 1215.1, 1196.1, 1172.1, 1163.6, 1148.9, 1150, 1156.7, 1186.4, 1198.9, 1192.5, 1187.5, 1183.9, 1188, 1195.4, 1193.4, 1185.6, 1171.9, 1182.3, 1142.8, 1154.8, 1008.1, 938.73, 842.74, 899.4, 989.67, 1128.1, 1042.3, 963.05, 947.41, 986.38, 989.88, 949.68, 955.03, 1029.4, 977.02, 1052, 1090.1, 1126.1, 1110.1, 1099.4, 1097.8, 1118.4, 1085.5, 1111.9, 1107.8, 1108.4, 1131.6, 1140.8, 1140.4, 1138.1, 1138.9, 1132.3, 1128.6, 1127.3, 1122.4, 1126.5, 1121, 1135.3, 1132.1, 1118.5, 1117.6, 1124.6, 1093.2, 247.16, 143.28, 634.91, 352.17, 498.85, 633.77, 750.8, 895.74, 1022.2, 1034.7, 1064.6, 1071.6, 1080.2, 1079.7, 1080, 1080.1, 1082.7, 1076.4, 1075.4, 1080.3, 1068.7, 1066.2, 1071.4, 1067.2, 1060.2, 1064.9, 1065.6, 1053, 1039.9, 1035.9, 1004.5, 1017.9, 1008.4, 1001.5, 1010.1, 1006.6, 989.85, 1005.7, 1024.5, 1004.8, 988.59, 999.78, 1001.1, 982.88, 994.52, 972.7, 1012.2, 1001.8, 998.44, 973.53, 974.88, 972.73, 948.82, 932.36, 836.81, 829.27, 771.71, 789.84, 762.99, 838.44, 798.99, 922.92, 880.81, 625.76, 866.19, 897.52, 865.3, 911.78, 788.7, 861.35, 849.3, 856.66, 829.61, 886.22, 866.08, 929.17, 901.35, 934.93, 925.85, 927.83, 941.24, 936.26, 924.11, 931.71, 914.34, 942.26, 944.47, 919.47, 920.1, 914.47, 829, 904.54, 899.42, 895.4, 790, 847.46, 903.43, 920.59, 920.94, 920.81, 917.64, 916.48, 923.67, 929.34, 909.56, 894.87, 788.82, 850.66, 891.4, 882.52, 899.33, 886.71, 898.87, 889.99, 874.51, 862.04, 886.25, 889.48, 886.07, 871.44, 874.34, 845.63, 867.87, 864.94, 868.59, 879.13, 845.15, 847.99, 858.99, 870.41, 860.78, 862.55, 846.88, 814.12, 794.13, 759.56, 712.65, 623.1, 671.37, 514.61, 694.29, 561.62, 625, 644.83, 788.62, 763.37, 725.02, 598.33, 610.91, 659.12, 585.53, 625.8, 645.08, 589.06, 587.4, 635.5, 540.99, 683.5, 556.12, 691.61, 696.57, 730.04, 655.84, 696.98, 675.71, 666.21, 658.75, 736.84, 553.63, 517.92, 406.79, 385.4, 283.86, 234.59, 136.04, 236.9, 152.67, 154.53, 189.62, 375.91, 444.11, 350.71, 381.92, 262.89, 269.87, 347.29, 184.09, 350.1, 259.11, 465.14, 139.44, 455.63, 254.18, 324.42, 399.88, 322.04, 309.96, 255.91, 434.53, 352.94, 396.85, 434.81, 416.64, 475.85, 432.42, 474.69, 473.77, 473.53, 613.01, 644.8, 596.89, 670.59, 646.29, 570.81, 541.7, 555.36, 538.72, 600.84, 579.03, 600.46, 569.41, 670.58, 651.02, 629.15, 692.9, 647.34, 705.53, 694.89, 690.59, 703.91, 688.43, 708.33, 705.97, 693.25, 708.91, 706.73, 704.09, 695.55, 694.81, 694.55, 691.59, 700.13, 684.98, 690.86, 680.56, 641.4, 670.47, 684.63, 684.07, 677.42, 676.95, 680.34, 676.67, 675.56, 678.48, 666.76, 669.76, 662.37, 672.63, 648.8, 658.39, 661.07, 649.8, 654.9, 650.77, 657.27, 656.25, 653.18, 653.98, 646.87, 650.92, 647.99, 648.52, 637.51, 641.36, 643.48, 643.23, 636.64, 633.61, 638.02, 633.66, 633.79, 634.06, 627.73, 630.67, 627.12, 610.78, 620.08, 625.59, 622.06, 618.02, 618.62, 614.87, 613.02, 610.48, 612.42, 610.55, 609.1, 602.86, 584.53, 600.73, 586.94, 597.82, 588.15, 597.22, 594.61, 583.3, 586.37, 585.61, 554.28, 571.78, 583.04, 581.94, 570.86, 587.8, 560.54, 581.41, 571.75, 570.76, 572.1, 565.19, 549.73, 557.73, 566.03, 547.75, 561.63, 524.96, 536.85, 561.59, 548.56, 526.56, 557.22, 550.48, 484.17, 511.2, 493.63, 477.31, 548.05, 477.09, 481.61, 461.13, 471.69, 445.13, 442.91, 444.12, 480.65, 378.4, 458.66, 395.17, 392.49, 454.96, 315.72, 393.3, 255.99, 285.76, 238.33, 192.23, 76.164, 207.63, 108.21, 135.62, 177.53, 78.159, 122.55, 103.97, 137.94, 49.394, 150.32, 94.946, 101.33, 67.568, 282.01, 223.59, 146.61, 39.988, 14.819, 123.2, 274.72, 194.28, 284.84, 244.47, 184.86, 214.81, 297.58, 108.43, 139.76, 150.85, 56.715, 258.98, 208.94, 116.48, 194.53, 236.66, 227.62, 136.43, 299.03, 268.37, 300.4, 297.7, 321.63, 273.71, 331.67, 334.12, 446.44, 383.32, 370.8, 357.81, 391.05, 400.18, 403.48, 437.31, 427.5, 433.7, 435.22, 321.93, 431.42, 454.47, 450.4, 343.91, 461.14, 420.52, 434.23, 309.03, 418.53, 400.83, 389.08, 455.18, 434.94, 320.39, 396.85, 441.24, 426.38, 451.71, 433.7, 447.51, 426.71, 411.88, 455.27, 414.26, 348.69, 427.89, 417.35, 417.43, 414.41, 346.45, 417.14, 458.72, 410.44, 413.79, 395.48, 432.67, 403.19, 405.72, 448.04, 414.43, 408.51, 445.09, 434.57, 438.42, 426.39, 437.24, 444.13, 430.96, 424, 427.88, 441.41, 446.96, 413.6, 445.44, 446.08, 439.28, 450.67, 445.25, 433.59, 448.93, 444.09, 447.95, 442.59, 446.94, 441.94, 440.11, 441.3, 441.79, 437.12, 434.99, 436.22, 439.02, 437.15, 438.28, 439.3, 436.84, 432.6, 431.06, 428.03, 424.16, 430.88, 420.96, 416.3, 425.49, 408.68, 412.35, 393.71, 378.67, 383, 355.68, 378.71, 368.81, 371.59, 354.75, 236.56, 370.87, 390.62, 391.14, 388.74, 388.64, 394.55, 398.95, 401.91, 409.16, 406.26, 403.87, 395.54, 356.95, 389.78, 402.68, 405.77, 408.78, 404.05, 401.92, 391.94, 395.22, 400.04, 379.46, 395.06, 387.09, 388.01, 373.22, 355.83, 375.36, 391.27, 338.55, 347.28, 375.39, 331.97, 288.49, 367.83, 368.53, 293.62, 332.77, 368.22, 289.08, 320.12, 319.86, 300.89, 276.9, 274.47, 311.13, 299.69, 319.84, 258.03, 248.64, 286.84, 290.23, 223.86, 252.31, 309.43, 269.56, 255.93, 225.55, 170.97, 220.52, 139.51, 140.46, 195.45, 163.02, 222.44, 176.7, 158.52, 171.51, 170.33, 162.16, 164.19, 171.49, 122.59, 73.018, 105.21, 56.189, 58.058, 4.5862, 15.617, 15.488, 4.4759, 1.4661, 0.09292, 0.28051, 0.00348, 0.04649, 0.06943, 0.00406, 7.104E-4, 0.00207, 4.6566E-6, 1.7489E-8, 0.00305, 0.00132, 8.7833E-9, 0.01238, 0.00482, 1.4311E-10, 5.0008E-4, 2.8266E-4, 1.9101E-5, 0.00266, 0.04299, 0.1735, 0.31309, 0.24935, 0.11883, 1.0741, 0.05053, 0.07904, 0.0023, 0.00249, 4.2653E-5, 5.9782E-4, 0.00203, 0.00244, 0.19288, 0.0039, 0.56338, 0.47836, 0.33345, 0.02306, 0.11238, 0.07327, 6.5137E-4, 6.1338E-6, 0.04761, 1.2329, 0.78835, 3.1513E-6, 1.0219E-5, 1.7817, 2.3108, 0.71755, 3.5395E-4, 1.9861, 0.16957, 1.6023, 0.60159, 0.45332, 2.0544, 2.565, 22.69, 0.35359, 0.17854, 34.561, 11.431, 13.182, 2.0851, 8.0437, 8.9117, 45.023, 8.9676, 16.511, 25.142, 27.032, 48.18, 4.436, 36.985, 59.912, 48.792, 2.4524, 34.87, 20.403, 20.847, 37.326, 29.085, 12.913, 49.672, 38.547, 30.959, 35.356, 43.868, 60.143, 48.434, 22.492, 35.265, 112.54, 99.374, 26.699, 10.98, 60.718, 79.803, 133.84, 64.409, 86.158, 113.86, 132.73, 158.6, 83.161, 87.886, 127.08, 42.106, 147.7, 90.911, 63.498, 35.128, 74.928, 92.344, 48.397, 17.394, 45.566, 68.368, 94.765, 179.54, 66.987, 67.916, 61.825, 116.8, 59.063, 112.21, 56.967, 144.54, 133.75, 121.68, 120.08, 59.042, 91.654, 184.43, 169.93, 192.22, 159.86, 176.51, 197.94, 177.45, 163.85, 221.98, 184.37, 211.41, 243.39, 257.82, 226.88, 179.72, 155.86, 178.85, 250.26, 247.79, 236.06, 181.69, 262.69, 257.1, 253.15, 235.44, 219.3, 258.04, 249.43, 242.14, 244.89, 237.39, 256.88, 267.07, 256.17, 271.92, 267.43, 251.4, 259.77, 254.68, 271.22, 264.6, 247.89, 262, 270.39, 269.18, 261.22, 259.24, 266.79, 265.58, 264.27, 265.19, 257.37, 261.41, 261.65, 264.39, 264.43, 269.22, 267.05, 265.37, 259.2, 265.68, 262.26, 262.93, 264.15, 263.66, 257.27, 260.05, 255.69, 263.01, 260.93, 260.54, 258.21, 262.42, 260.03, 259.17, 255.25, 259.75, 255.06, 255.66, 249.97, 247.36, 234.97, 228.5, 231.08, 227.5, 234.64, 232.94, 239.8, 209.94, 228.54, 230.05, 237.72, 241.65, 235.08, 240.51, 241.94, 251.35, 248.38, 245.79, 243.88, 225.67, 234.86, 235.03, 245.02, 250.92, 248.9, 250.83, 237.51, 239.85, 246.93, 235.11, 231.33, 216.91, 217.8, 217.65, 221.97, 230.1, 234.53, 226.37, 223.43, 220.88, 211.46, 220.39, 224.22, 230.47, 231.62, 234.2, 223.95, 227.98, 236.6, 234.15, 227.83, 227.65, 230.81, 235.59, 235.82, 231.09, 232.94, 233.98, 234.46, 234.56, 229.84, 231.36, 231.51, 226.14, 226.28, 227.12, 228.79, 220.64, 213.93, 214.1, 209.13, 213.48, 214.67, 209.39, 217.33, 212.16, 211.47, 221.35, 210.57, 212.61, 219.02, 202.81, 217.54, 216.61, 209.91, 216.19, 214.94, 216.13, 218.7, 215.14, 217.21, 217.74, 213.13, 216.3, 214.98, 206.07, 174.11, 205.02, 208.81, 209.39, 215.73, 212.94, 205.82, 210.52, 210.02, 207.93, 205.84, 206.68, 203.65, 207.41, 200.17, 189.36, 198.3, 203.57, 192.83, 207.63, 204.76, 199.51, 204.65, 201.78, 199.91, 188.08, 201.74, 205.87, 199.5, 204.27, 203.83, 176.49, 202.07, 200.24, 194.64, 198.74, 192.75, 183.16, 184.9, 182.31, 173.67, 169.79, 157.58, 164.05, 151.05, 161.62, 149.31, 156.08, 129.67, 138.31, 112.13, 98.143, 75.201, 86.831, 45.864, 31.112, 14.485, 9.4762, 3.2093, 0.96578, 1.2463, 0.00509, 0.00628, 6.1337E-5, 0.00613, 0.00293, 2.7795E-4, 0.01092, 0.01664, 2.6148E-7, 4.4296E-7, 0.07612, 0.04313, 0.21956, 0.12743, 8.4916E-4, 5.5798E-4, 0.02273, 0.01967, 0.44451, 0.92326, 0.54474, 3.5428, 3.2357, 10.707, 16.482, 9.886, 21.569, 28.114, 48.055, 66.73, 74.234, 81.625, 84.124, 79.787, 37.491, 14.747, 39.071, 26.208, 44.239, 72.779, 83.46, 94.808, 88.344, 89.636, 66.892, 54.09, 68.157, 60.962, 64.715, 76.305, 85.528, 83.847, 87.779, 88.421, 84.869, 91.771, 88.32, 90.308, 86.281, 87.303, 88.422, 88.679, 89.39, 88.132, 83.369, 83.566, 82.912, 75.175, 80.776, 79.257, 80.597, 73.458, 77.905, 77.833, 70.175, 72.947, 78.174, 75.189, 76.631, 74.4, 74.727, 73.29, 72.14, 69.911, 71.034, 66.865, 66.143, 67.355, 64.138, 63.309, 65.551, 62.389, 62.534, 60.603, 58.193, 58.544, 63.189, 57.528, 51.489, 55.626, 56.231, 57.362, 45.366, 50.869, 41.115, 46.988, 49.724, 48.909, 30.514, 43.704, 42.128, 30.525, 36.748, 40.199, 43.726, 33.286, 33.504, 27.058, 26.358, 32.802, 44.725, 14.765, 42.926, 20.657, 13.523, 24.695, 33.157, 24.009, 16.635, 16.368, 7.9996, 5.584, 3.4957, 2.8647, 7.0328, 1.5124, 2.2063, 0.51644, 0.36879, 0.04119, 6.3279E-4, 1.7415E-4, 3.7521E-4, 5.3469E-8, 2.8066E-10, 1.0377E-6, 3.0842E-8, 1.5846E-11, 1.5151E-15, 1.0708E-24, 3.7933E-19, 1.7064E-31, 5.4369E-28, 2.2666E-30, 4.4556E-25, 5.7592E-32, 5.897E-31, 1.1106E-34, 5.6056E-26, 3.8378E-25, 2.8026E-42, 3.8719E-13, 1.1657E-13, 8.9292E-16, 1.4186E-16, 1.3036E-24, 2.588E-22, 1.1045E-34, 0, 0, 0, 0, 1.0178E-26, 7.1014E-30, 0, 2.9273E-39, 1.1239E-32, 3.8549E-23, 5.6052E-42, 7.3094E-19, 6.0929E-16, 5.5121E-18, 2.3435E-24, 1.3224E-20, 1.6758E-25, 6.7262E-41, 0, 2.7001E-24, 8.4528E-21, 4.036E-35, 4.8532E-31, 3.9255E-24, 1.2295E-13, 3.6591E-13, 1.6665E-9, 6.8228E-11, 4.0695E-7, 2.9018E-7, 2.0789E-8, 1.7814E-4, 0.00395, 2.1533E-7, 1.9849E-4, 0.04107, 0.00117, 4.5425E-4, 0.02567, 0.16974, 0.00639, 0.39663, 0.25037, 0.45906, 0.1886, 2.6982, 0.82183, 0.11237, 2.7566, 1.2742, 2.9316, 1.0973, 5.9606, 6.5725, 1.6479, 1.4673, 5.2935, 2.3655, 4.6549, 7.5313, 0.35676, 0.86499, 1.3548, 7.0495, 10.407, 4.3286, 7.9442, 2.9261, 6.932, 5.6232, 0.64143, 7.5948, 6.1491, 2.529, 2.0487, 4.2599, 1.0446, 0.29295, 6.3761, 2.9458, 1.7699, 6.0928, 3.6646, 1.7876, 2.408, 0.66266, 4.4513, 0.93203, 0.85524, 2.2932, 9.9294, 3.0625, 5.8246, 11.571, 3.3603, 3.2869, 6.7457, 5.6965, 9.3294, 14.163, 12.645, 9.3252, 10.73, 8.1644, 4.2817, 2.7197, 0.4428, 0.3128, 0.13768, 0.50237, 1.6245, 0.20066, 0.34404, 7.3625, 3.7816, 0.74096, 2.6308, 10.029, 1.236, 2.4686, 1.2292, 5.9758, 2.889, 11.223, 8.831, 1.2337, 1.7944, 3.9746, 3.9565, 0.01627, 0.0605, 3.5486, 4.7014, 9.147, 3.4903, 3.5722, 8.0998, 3.6642, 5.2892, 7.2591, 3.977, 8.5388, 5.1624, 7.565, 9.9552, 9.6446, 12.638, 4.5061, 7.1547, 7.3543, 13.305, 10.112, 8.781, 11.673, 8.1181, 11.434, 11.267, 8.3938, 12.657, 9.9163, 12.386, 11.051, 11.335, 12.212, 10.52, 12.383, 12.032, 11.923, 12.077, 11.598, 12.226, 11.523, 11.217, 9.5305, 9.1011, 9.6154, 10.616, 9.1245, 10.872, 10.928, 8.3951, 8.7028, 10.255, 9.2282, 9.5145, 9.7329, 10.328, 10.425, 9.5385, 9.5318, 11.686, 10.302, 10.016, 10.362, 11.549, 10.663, 10.183, 11.042, 10.978, 10.313, 7.9464, 4.8569, 8.3789, 9.4906, 9.7458, 10.188, 10.937, 10.827, 9.413, 9.2731, 10.429, 10.751, 9.3169, 8.626, 8.8923, 10.38, 9.3341, 9.0336, 8.9041, 8.5891, 9.1649, 9.0918, 9.6158, 8.8498, 7.7891, 8.9056, 9.8988, 9.3414, 8.2771, 7.7867, 9.6908, 9.5402, 9.6268, 7.719, 9.0066, 8.8097, 8.8569, 8.5365, 8.0197, 8.1248, 7.3839, 6.7832, 6.5543, 6.7926, 6.9028, 7.4983, 7.9487, 7.95, 7.156, 7.007, 6.9665, 6.8714, 7.0699, 7.3743, 7.4228, 7.5613, 7.6475, 7.7399, 7.7679, 7.8253, 7.6997, 7.528, 7.4049, 7.4503, 7.3894, 7.2263, 7.1199 ]
	);

	var AM0e = null;
	var AM15e = null;
		
	return {
		getAM0: function() { return AM0; },
		getAM15: function() { return AM15; },
		
		getAM0e: function() {
			if (!AM0e)
				AM0e = AM0.invx(1.2398);
			
			return AM0e;
		},
		
		getAM15e: function() {
			if (!AM15e)
				AM15e = AM15.invx(1.2398);
			
			return AM15e;
		}
	};	
})();