﻿"use strict";

Math.DPI = 2 * Math.PI;

Math.HPI = 0.5 * Math.PI;

Math.DEG = Math.PI / 180;

Math.sinc = function (x) {
	return Math.abs(x) < 1e-10 ? 1 : Math.sin(x) / x;
};

Math.zero = function(x) {
	return 0;
};

Math.constant = function(value) {
	return function(x) { return value; };
};

Math.toDegrees = function(x) { return x / Math.DEG; };

Math.toRadians = function(x) { return x * Math.DEG; };

if (!Math.sign) {
	Math.sign = function(x) {
		// If x is NaN, the result is NaN.
		// If x is -0, the result is -0.
		// If x is +0, the result is +0.
		// If x is negative and not -0, the result is -1.
		// If x is positive and not +0, the result is +1.
		return ((x > 0) - (x < 0)) || +x;
	};
}

if (!Math.atan2) {
    Math.atan2 = function(y, x){
		if (x === 0) {
			if (y === 0) return 0;
			return y < 0 ? -Math.HPI : Math.HPI;
		}
		
		var angle = Math.atan(y / x);
		if (x > 0)
			return angle;

		if (y < 0)
			angle -= Math.PI;
		else
			angle += Math.PI;
		
		return angle;
	};
}

Math.step = function(x, zeroValue) {
	if (isNaN(x))
		return NaN;

	if (x > 0)
		return 1;

	if (x < 0)
		return 0;

	return zeroValue === undefined ? 0.5 : zeroValue;
}

Math.constrain = function(x, min, max) {
	if (max < min) {
		var tmp = min;
		min = max;
		max = tmp;
	};

	if (x < min)
		return min;
		
	if (x > max)
		return max;
		
	return x;
};

Math.sigmoid = function(x) {
	return 1 / (1 + Math.exp(-x));
};

Math.lorentz = function(x) {
	return 1 / (x * x + 1);
};

Math.doppler = function(x) {
	return Math.exp(-Math.LN2 * x * x)
};

Math.fact = (function() {
	var memorized = [1, 1];
	
	return function(n) {
		var m = memorized.length - 1;
		while (n > m) {
			memorized.push(memorized[m] * (m + 1));
			m++;
		}
		
		return memorized[n];
	};
})();

Math.trapez = function(f, a, b, n) {
	var h = (b - a) / n;
	var sum = 0.5 * ( f(a) + f(b) );
	for (var i = 1; i < n; i++)
		sum += f(a + i * h);
	
	return h * sum;
};

Math.euler = function(eqns, initial, step, maxtime) {
	var t = 0;
	var time = [t];
	
	var y = initial;
	var signals = [];
	var n = y.length;
	
	for (var i = 0; i < n; i++)
		signals.push( [y[i]] );
	
	while (t <= maxtime) {
		var d = eqns(t, y);
		t += step;
		time.push(t);
		for (var i = 0; i < n; i++) {
			y[i] += step * d[i];
			signals[i].push( y[i] );
		}
	}
	
	return { t: time, y: signals };
};

Math.secant = function(f, a, b, xtol, maxiter) {
	if (xtol === undefined)
		xtol = 1e-8;
	
	if (maxiter === undefined)
		maxiter = 100;

	var fa = f(a);
	var iter = 0;
	while (Math.abs(a - b) > xtol && iter < maxiter) {
		var fb = f(b);
		var tmp = (a * fb - b * fa) / (fb - fa);
		a = b;
		fa = fb;
		b = tmp;
		iter++;
	}
	
	return b;
};

Math.rk4 = function(eqns, initial, step, maxtime) {
	var t = 0;
	var time = [t];
	
	var y = initial;
	var signals = [];
	var n = y.length;
	
	for (var i = 0; i < n; i++)
		signals.push( [y[i]] );
	
	var half = step / 2;
	var sixth = step / 6;
	while (t <= maxtime) {
		var k1 = eqns(t, y);
		var u = [];
		for (var i = 0; i < n; i++)
			u.push( y[i] + half * k1[i] );
		
		var k2 = eqns(t + half, u);
		for (var i = 0; i < n; i++)
			u[i] = y[i] + half * k2[i];
		
		var k3 = eqns(t + half, u);
		for (var i = 0; i < n; i++)
			u[i] = y[i] + step * k3[i];
		
		t += step;
		var k4 = eqns(t, u);
		
		time.push(t);
		for (var i = 0; i < n; i++) {
			y[i] += sixth * (k1[i] + 2 * (k2[i] + k3[i]) + k4[i]);
			signals[i].push( y[i] );
		}
	}
	
	return { t: time, y: signals };
};

Array.prototype.max = function() {
	var i = this.length;
	var res = -Infinity;
	while (i--) {
		if (this[i] > res)
			res = this[i];
	}
	
	return res;
};

Array.prototype.min = function() {
	var i = this.length;
	var res = Infinity;
	while (i--) {
		if (this[i] < res)
			res = this[i];
	}
	
	return res;
};

if(!Array.prototype.includes) {
	Array.prototype.includes = function(value) { return this.indexOf(value) >= 0; };
}

if (!Array.prototype.last) {
    Array.prototype.last = function() {
        return this[this.length - 1];
    };
}

if (!Array.prototype.sum) {
	Array.prototype.sum = function() {
	    var total = 0;
	    var i = this.length; 
	
	    while (i--)
	    	total += this[i];
	    		
	    return total;
	};
}

Array.filled = function(a, n) {
	var result = [];
	result.length = n;
	result.fill(a);
	return result;
};

Array.linspace = function(a, b, n) {
	var result = [];
	var step = (b - a) / (n - 1);
	for (var i = 0; i < n; i++)
		result.push(a + i * step);
		
	return result;
};

Array.logspace = function(a, b, n) {
	var result = [];
	var q = b / a;
	for (var i = 0; i < n; i++)
		result.push(a * Math.pow(q, i / (n - 1)));
		
	return result;
};

Object.clone = function(obj) {
	var newobj = Object.create(Object.getPrototypeOf(obj));
	return Object.assign(newobj, obj);
};

Object.fillEmpty = function(target, source) {
	if (target === undefined)
		target = { };

	for (var p in source)
		if (Object.prototype.hasOwnProperty.call(source, p) && !Object.prototype.hasOwnProperty.call(target, p))
			target[p] = source[p];
			
	return target;
};

Object.isDOM = function(obj) {
	return (typeof obj == "object" && "nodeType" in obj && obj.nodeType === 1 && obj.cloneNode);
}

if (!Object.assign)
	Object.assign = function(target) {
		if (target === undefined || target === null)
			throw new TypeError('Target is undefined or null');
	
		var res = Object(target);
		for (var i = 1; i < arguments.length; i++) {
			var source = arguments[i];
			if (source === undefined || source === null)
				continue;
				
			source = Object(source);
			var keys = Object.keys(source);
			for (var k = 0, len = keys.length; k < len; k++) {
			  var key = keys[k];
			  if (Object.prototype.hasOwnProperty.call(source, key))
			  	res[key] = source[key];
			}
		}
	
		return res;
	};

Number.TIMES = '&times;';
Number.MINUS = '&minus;';

Number.prototype.toHTML = function(n) {
	var res = this.toPrecision(n);
	var i = res.indexOf('e');
	if (i >= 0) {
		var m = res.substr(0, i);
		var e = res.substr(i + 1);
		if (e.charAt(0) === '+')
			e = e.substr(1);
			
		res = m + Number.TIMES + '10<sup>' + e + '</sup>';
	}
		
	return res.replace('-', Number.MINUS);
}

function PreciseFormat(digits) {
	return function(value) { return value.toPrecision(digits); };
}

function FixedFormat(digits) {
	return function(value) { return value.toFixed(digits); };
}

function FixedDegrees(digits) {
	return function(x) { return (x / Math.DEG).toFixed(digits) + '&deg;'; };
}

function HTMLFormat(digits) {
	return function(value) { return value.toHTML(digits); };
}


function Multiplier(factor) {
	return function(value) { return factor * value; };
}

function Divider(factor) {
	return function(value) { return value / factor; };
}

function Named(obj, name) {
	return {
		getObj: function() { return obj; },
		toString: function() { return name; }
	};
}

function Toggler(value, onChange) {
	var original = value;
	
	return {
		getValue: function() { return value; },
		
		reset: function(raise) {
			if (value === original)
				return;
				
			value = original;
			if (raise && onChange)
				onChange();
		},
		
		toggle: function(raise) {
			value = !value;
			if (raise && onChange)
				onChange();
		}
	}
}

function Scalable(value, config) {
	var original = value;
	var steps = 0;
	if (!config)
		config = {};
		
	var min = config.min;
	var max = config.max;
	var maxSteps = config.maxSteps;
	var onChange = config.onChange;
	var factor = config.factor || 2;
	
	return {
		getValue: function() { return value; },
		
		reset: function(raise) {
			if (steps === 0)
				return;
				
			value = original;
			steps = 0;
			if (raise && onChange)
				onChange();
		},
		
		inc: function(raise) {
			if (maxSteps && steps >= maxSteps)
				return;
		
			var newVal = value * factor;
			if (newVal > max || newVal < min)
				return;
			
			value = newVal;
			steps++;
			if (raise && onChange)
				onChange();
		},
		
		dec: function(raise) {
			if (maxSteps && steps <= -maxSteps)
				return;
		
			var newVal = value / factor;
			if (newVal > max || newVal < min)
				return;
			
			value = newVal;
			steps--;
			if (raise && onChange)
				onChange();
		}
	};
}

function setScaledValue(slider, value, range) {
	if (typeof slider === 'string')
		slider = document.getElementById(slider);
		
	var min = parseInt(slider.min);
	var max = parseInt(slider.max);
	slider.value = min + (max - min) * (value - range.min) / (range.max - range.min);
}

function setLogScaledValue(slider, value, range) {
	if (typeof slider === 'string')
		slider = document.getElementById(slider);
		
	var min = parseInt(slider.min);
	var max = parseInt(slider.max);
	slider.value = min + (max - min) * Math.log(value / range.min) / Math.log(range.max / range.min);
}

function getScaledValue(slider, range) {
	if (typeof slider === 'string')
		slider = document.getElementById(slider);
		
	var min = parseInt(slider.min);
	var max = parseInt(slider.max);
	var value = parseInt(slider.value);
	return range.min + (range.max - range.min) * (value - min) / (max - min);
}

function getLogScaledValue(slider, range) {
	if (typeof slider === 'string')
		slider = document.getElementById(slider);
		
	var min = parseInt(slider.min);
	var max = parseInt(slider.max);
	var value = parseInt(slider.value);
	return range.min * Math.pow(range.max / range.min, (value - min) / (max - min));
}

function toggleVisible(element) {
	if (typeof element === 'string')
		element = document.getElementById(element);
		
	if (window.getComputedStyle(element).display === 'none')
		element.style.display = 'block';
	else
		element.style.display = 'none';
}

function openUrl(url, config) {
	var specs = "location=0,toolbar=0,menubar=0,scrollbars=0,status=0";
	if (config) {
		if ('width' in config)
			specs += ',width=' + config.width;
		if ('height' in config)
			specs += ',height=' + config.height;
	}
	
	var wnd = window.open(url, config.name || "_blank", specs);
	wnd.focus();
	wnd.moveTo(window.screenLeft + 50, window.screenTop + 50);
	return wnd;
}

function showGraph(config, data) {
	var wnd = openUrl('graph.html', config);
	wnd.addEventListener('load', function(){ wnd.postMessage(data, '*'); }, false);
	//setTimeout(function(){ wnd.postMessage(info, '*'); }, 500);
}

function showImage(url, config) {
	return openUrl('image.html?src=' + encodeURIComponent(url), config);
}

function parseKeyValuePairs(text, separ) {
	var result = {};
	var parts = text.split(separ || '&');
	
	for (var i = 0; i < parts.length; i++) {
		var pair = parts[i].split('=');
		if (pair.length >= 2)
		{
			var key = decodeURIComponent(pair[0]);
			var value = decodeURIComponent(pair[1]);
			result[key] = value;
		}
	}
	
	return result;
}

